************** Parms **************
clear *
set more off
global path ~/replication_eer

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)

************* Prelims *************

cd $path
use data/fullpanel0_march2013.dta, clear

drop ryear
gen ryear = round(year)

duplicates report ccode_cov ryear
duplicates list ccode_cov ryear

drop if ryear<1981 | ryear>2010

** get PCE/pop from PWT71

merge m:1 ccode ryear using data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

* generate vars
xtset ccode_cov ryear

gen ln_mean = ln(mean)
gen ln_gini = ln(gini)
gen ln_rcp = ln(rcp)

label var ln_mean "$ \ln \bar{y}_{it} $"
label var ln_gini "$ \ln G_{it} $"
label var h_200d "$ H_{it} $"
label var ln_rcp "$ \ln PCE^P_{it} $"

encode regWB, gen(region) //region dummies

************* Table 5 *************

*** final data starts here
**** clean for first models: balanced case (ignore unbalancedness)

egen anymiss = rowmiss(h_200d ln_mean ln_gini)
drop if anymiss

bys ccode_cov (ryear): gen Ti = _N 
tab Ti if ~anymiss, gen(Ti_)

tab stype if ~anymiss, gen(S_)

bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
cap bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
cap bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
forv i = 1981(1)2010 {
	gen y_`i' =  (ryear==`i') 
	bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
}

* flexible unbalanced
fhetprob h_200d  ln_mean ln_gini ib(last).Ti##c.ln_gini_bar ib(last).Ti##c.ln_gini_bar ///
	y_1981-yb_2009 S_2-S_4 Sb_* if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov)	

estimate store fhet

save ./data/interim, replace

*** full sample
	
use ./data/interim, clear

drop if ryear < 1981 | ryear>2010 
*drop if ryear<2000 


bys ccode_cov stype (ryear): gen tag_obs = _n 
bys ccode_cov stype (ryear): gen tag_tot = _N 

drop if (tag_obs!=1 & tag_obs!=tag_tot)
drop if tag_tot<2

egen panelid = group(ccode_cov stype), label
bys ccode_cov (ryear): gen  new_t = _n
xtset panelid new_t

bys panelid (ryear): gen duration = year[2] - year[1]
tab duration


bys panelid (ryear):  gen gini_first = ln_gini[1]
bys panelid (ryear):  gen gini_last = ln_gini[2]

bys panelid (ryear):  gen mean_first = ln_mean[1]
bys panelid (ryear):  gen mean_last = ln_mean[2]

estimate restore fhet

*replace Ti = 2 if Ti==1 // not needed can only decompose if 2 are available

gen gini_old = ln_gini
replace ln_gini  = gini_first
predict double H_y1_g0 // if e(sample)

replace ln_gini = gini_old
gen mean_old = ln_mean
replace ln_mean  = mean_first
predict double H_y0_g1 //if e(sample)


by panelid (ryear):  gen H_y0_g0 = h_200d[1]
by panelid (ryear):  gen H_y1_g1 = h_200d[2]

drop if tag_obs==1
unique ccode // just as the other sample

keep ccode_cov ccode year ryear H_* duration regWB  gini_* mean_*

gen delta = ((H_y1_g1) - (H_y0_g0) ) /duration *100
gen Y = ((H_y1_g0) - (H_y0_g0)) /duration *100
gen D = ((H_y0_g1) - (H_y0_g0)) /duration  *100
gen R = delta - (Y + D)
gen B = Y + D
gen se = (delta - B)^2 

gen d_gini = (gini_last - gini_first) /duration *100
gen d_mean = (mean_last - mean_first) /duration *100

* loop over regions

matrix A = J(7,15,.)

tab regWB

local reglist EAP ECA LAC MNA SAS SSA ALL

local i = 1
foreach x of loc reglist {
	
	if `i' < 7 {
		qui corr Y D if regWB=="`x'", cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R if regWB=="`x'", cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B if regWB=="`x'"
		mat A[`i',13] = `r(rho)'^2

		sum se if regWB=="`x'", mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	} 
	else {
		qui corr Y D, cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)')  * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R, cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B 
		mat A[`i',13] = `r(rho)'^2

		sum se, mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	}
	
	local ++i
}

mat colnames A = VarY VarD CovYD ShareY ShareD AltY AltD VarB  VarR CovBR ShareB ShareR pR2 RMSE N
mat rownames A = "East Asia and Pacific" "Europe and Central Asia" "Latin America and Caribbean" ///
		 "Middle East and North Africa" "South Asia" "Sub-Saharan Africa" "All developing"
mat li A 

corr delta B
di r(rho)^2

sum  duration, d

mat B = A[.,1..5],  A[.,14..15]
frmttable, s(B) store(tab1) var sf(f) sd(3,3,3,2,2,2,0) 

* do we need this for the figures?
saveold ./data/results_2d_whole, replace version(12)

*** 1981-2000 spells
use ./data/interim, clear

drop if ryear < 1981 | ryear>1999 

bys ccode_cov stype (ryear): gen tag_obs = _n 
bys ccode_cov stype (ryear): gen tag_tot = _N 

drop if (tag_obs!=1 & tag_obs!=tag_tot)
drop if tag_tot<2

egen panelid = group(ccode_cov stype), label
bys ccode_cov (ryear): gen  new_t = _n
xtset panelid new_t

bys panelid (ryear): gen duration = year[2] - year[1]
tab duration


bys panelid (ryear):  gen gini_first = ln_gini[1]
bys panelid (ryear):  gen gini_last = ln_gini[2]

bys panelid (ryear):  gen mean_first = ln_mean[1]
bys panelid (ryear):  gen mean_last = ln_mean[2]

estimate restore fhet

gen gini_old = ln_gini
replace ln_gini  = gini_first
predict double H_y1_g0 // if e(sample)

replace ln_gini = gini_old
gen mean_old = ln_mean
replace ln_mean  = mean_first
predict double H_y0_g1 //if e(sample)


by panelid (ryear):  gen H_y0_g0 = h_200d[1]
by panelid (ryear):  gen H_y1_g1 = h_200d[2]

drop if tag_obs==1

keep ccode_cov ccode year ryear H_* duration regWB  gini_* mean_*

gen delta = ((H_y1_g1) - (H_y0_g0) ) /duration *100
gen Y = ((H_y1_g0) - (H_y0_g0)) /duration *100
gen D = ((H_y0_g1) - (H_y0_g0)) /duration  *100
gen R = delta - (Y + D)
gen B = Y + D
gen se = (delta - B)^2 

gen d_gini = (gini_last - gini_first) /duration *100
gen d_mean = (mean_last - mean_first) /duration *100

* loop over regions

matrix A = J(7,15,.)

tab regWB

local reglist EAP ECA LAC MNA SAS SSA ALL

local i = 1
foreach x of loc reglist {
	
	if `i' < 7 {
		qui corr Y D if regWB=="`x'", cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R if regWB=="`x'", cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B if regWB=="`x'"
		mat A[`i',13] = `r(rho)'^2

		sum se if regWB=="`x'", mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	} 
	else {
		qui corr Y D, cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)')  * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R, cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B 
		mat A[`i',13] = `r(rho)'^2

		sum se, mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	}
	
	local ++i
}

mat colnames A = VarY VarD CovYD ShareY ShareD AltY AltD VarB  VarR CovBR ShareB ShareR pR2 RMSE N
mat rownames A = "East Asia and Pacific" "Europe and Central Asia" "Latin America and Caribbean" ///
		 "Middle East and North Africa" "South Asia" "Sub-Saharan Africa" "All developing"
mat li A 

corr delta B
di r(rho)^2

sum  duration, d

mat B = A[.,1..5],  A[.,14..15]
frmttable, s(B) append(tab1) var sf(f) sd(3,3,3,2,2,2,0) 

saveold ./data/results_2d_early, replace version(12)

*** 2000-2010 spells

use ./data/interim, clear

drop if ryear<2000 | ryear>2010 

bys ccode_cov stype (ryear): gen tag_obs = _n 
bys ccode_cov stype (ryear): gen tag_tot = _N 

drop if (tag_obs!=1 & tag_obs!=tag_tot)
drop if tag_tot<2

egen panelid = group(ccode_cov stype), label
bys ccode_cov (ryear): gen  new_t = _n
xtset panelid new_t

bys panelid (ryear): gen duration = year[2] - year[1]
tab duration


bys panelid (ryear):  gen gini_first = ln_gini[1]
bys panelid (ryear):  gen gini_last = ln_gini[2]

bys panelid (ryear):  gen mean_first = ln_mean[1]
bys panelid (ryear):  gen mean_last = ln_mean[2]

estimate restore fhet

gen gini_old = ln_gini
replace ln_gini  = gini_first
predict double H_y1_g0 

replace ln_gini = gini_old
gen mean_old = ln_mean
replace ln_mean  = mean_first
predict double H_y0_g1

by panelid (ryear):  gen H_y0_g0 = h_200d[1]
by panelid (ryear):  gen H_y1_g1 = h_200d[2]

drop if tag_obs==1

keep ccode_cov ccode year ryear H_* duration regWB  gini_* mean_*

gen delta = ((H_y1_g1) - (H_y0_g0) ) /duration *100
gen Y = ((H_y1_g0) - (H_y0_g0)) /duration *100
gen D = ((H_y0_g1) - (H_y0_g0)) /duration  *100
gen R = delta - (Y + D)
gen B = Y + D
gen se = (delta - B)^2 

gen d_gini = (gini_last - gini_first) /duration *100
gen d_mean = (mean_last - mean_first) /duration *100

* loop over regions

matrix A = J(7,15,.)

tab regWB

local reglist EAP ECA LAC MNA SAS SSA ALL

local i = 1
foreach x of loc reglist {
	
	if `i' < 7 {
		qui corr Y D if regWB=="`x'", cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R if regWB=="`x'", cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B if regWB=="`x'"
		mat A[`i',13] = `r(rho)'^2

		qui sum se if regWB=="`x'", mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	} 
	else {
		qui corr Y D, cov
		mat A[`i',1] = `r(Var_1)'
		mat A[`i',2] = `r(Var_2)'
		mat A[`i',3] = `r(cov_12)'
		mat A[`i',4] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)')  * 100
		mat A[`i',5] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		* caselli style
		mat A[`i',6] = (`r(Var_1)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',7] = (`r(Var_2)' )/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr B R, cov
		mat A[`i',8] = `r(Var_1)'
		mat A[`i',9] = `r(Var_2)'
		mat A[`i',10] = `r(cov_12)'
		mat A[`i',11] = (`r(Var_1)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		mat A[`i',12] = (`r(Var_2)' + `r(cov_12)')/ (`r(Var_1)' + `r(Var_2)' + 2*`r(cov_12)') * 100
		
		qui corr delta B 
		mat A[`i',13] = `r(rho)'^2

		qui sum se, mean
		di sqrt(`r(mean)')
		mat A[`i',14] = sqrt(`r(mean)')
		mat A[`i',15] = `r(N)'
	}
	
	local ++i
}

mat colnames A = VarY VarD CovYD ShareY ShareD AltY AltD VarB  VarR CovBR ShareB ShareR pR2 RMSE N
mat rownames A = "East Asia and Pacific" "Europe and Central Asia" "Latin America and Caribbean" ///
		 "Middle East and North Africa" "South Asia" "Sub-Saharan Africa" "All developing"
mat li A 


corr delta B
di r(rho)^2

sum  duration, d

mat B = A[.,1..5],  A[.,14..15]
frmttable using ./tables/Table_5.tex, tex fra s(B) append(tab1) var sf(f) sd(3,3,3,2,2,2,0) 

***********************************

saveold ./data/results_2d_late, replace version(12)

***********************************
*% EOF
