************** Parms **************
clear *
set more off
global path ~/replication_eer
cd $path

************* Prelims *************

use ./data/fullpanel1.dta, clear

keep ccode_cov ryear ccode coverage regWB-regINC cname region 

*need to tsappend until 2030
replace ryear=ryear+30
drop if ryear>2030

merge m:1 ccode_cov ryear using ./data/fullpanel1.dta
xtset ccode_cov ryear
format %15s cname

drop lastyear endflag

drop _merge
drop region
merge m:1 ccode ryear using ./data/newWBpop_bycountry.dta
drop if _merge==2
xtset ccode_cov ryear

drop _merge
merge m:1 ccode ryear using ./data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

merge m:1 ccode ryear using ./data/wdiPCE_capita.dta, keepusing(pcepc_wdi)
drop country isocode

drop if _merge==2
drop _merge
xtset ccode_cov ryear

* clean region names
replace region =  subinword(region,"(all income levels)","",.) 
replace region =  subinword(region,"&","and",.)
replace region =  trim(region)

* create joint PCE growth series
drop l_rcp
gen lnrcp = ln(rcp)
gen lnpce_wdi = ln(pcepc_wdi)

reg lnrcp lnpce_wdi, cluster(ccode_cov)

gen gpce_wdi = (lnpce_wdi-l.lnpce_wdi) 
gen gpce_pwt = (lnrcp-l.lnrcp) 

by ccode_cov (ryear): egen lastyear_temp = lastnm(ryear) if h_125d!=.
by ccode_cov (ryear): egen lastyear = max(lastyear_temp) 

by ccode_cov (ryear): egen nmiss_wdi = total(missing(gpce_wdi)) if ryear>=1981 & ryear<2011
by ccode_cov (ryear): egen nmiss_wdi2 = max(nmiss_wdi) if ryear<2011

by ccode_cov (ryear): egen nmiss_pwt = total(missing(gpce_pwt)) if ryear>=1981 & ryear<2011
by ccode_cov (ryear): egen nmiss_pwt2 = max(nmiss_pwt) if ryear<2011

* region indicators
encode regWB, gen(region2)

* create a joint series that is always the longest of either series
gen gpce_joint = gpce_wdi if ryear<2011
replace gpce_joint = gpce_pwt if ryear<2011 & nmiss_pwt2<nmiss_wdi2

* carry forward with observed pce growth rates until 2010!
gen ln_mean_pce = ln_mean  if ryear==lastyear
replace ln_mean_pce = l.ln_mean_pce + gpce_joint if ryear>lastyear & ryear<2011

* unbalanced data, get aux indicators
cap drop anymiss ln_mean_bar ln_gini_bar y_* yb_* Ti T_* S_* Sb_*
egen anymiss = rowmiss(h_125d ln_mean ln_gini lnrcp)

mark touse
markout touse h_125d ln_mean ln_gini 

bys ccode_cov touse (ryear): gen Ti = _N if touse

tab Ti, gen(T_) 

tab stype if touse, gen(S_)

bys ccode_cov touse (ryear): egen ln_mean_bar = mean(ln_mean) if touse
bys ccode_cov touse (ryear): egen ln_gini_bar = mean(ln_gini) if touse
bys ccode_cov touse (ryear): egen Sb_2 = mean(S_2) if touse
bys ccode_cov touse (ryear): egen Sb_3 = mean(S_3) if touse
bys ccode_cov touse (ryear): egen Sb_4 = mean(S_4) if touse

forv i = 1981(1)2010 {
	gen y_`i' =  (ryear==`i') if touse
	bys ccode_cov touse (ryear): egen yb_`i' = mean(y_`i') if touse
}

xtset ccode_cov ryear

* flexible unbalanced
fhetprob h_125d  ln_mean ln_gini ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
	y_1981-yb_2009 S_2-S_4 Sb_* if Ti>1 & touse, het(ib(last).Ti) vce(cluster ccode_cov)
	
estimates store hetglm	

margins, eydx(ln_mean ln_gini) nose

* don't have info on Ti==1
replace Ti = 2 if Ti==1

predict double yhat if e(sample)

* move data forward in time
ds y_*
local vars `r(varlist)'
foreach x of local vars {
	replace `x' = 0 if ryear>lastyear
}

ds yb_* S_* Sb_* ln_gini* ln_mean_bar Ti 
local vars `r(varlist)'
foreach x of local vars {
	replace `x' = l.`x' if ryear>lastyear
}

replace ln_mean  = ln_mean_pce if missing(ln_mean)

predict double yhat_halfout if ryear==2010

* "in-sample" test
mean yhat_halfout [aweight=pop_wb] if ryear==2010, over(region2)
mean yhat_halfout [aweight=pop_wb] if ryear==2010

* get the data for the 3 scenarios
gen p0010 = (ryear<=2010&ryear>1999)
gen p9010 = (ryear<=2010&ryear>1989)
gen p8010 = (ryear<=2010&ryear>1979)
gen p8000 = (ryear<2000&ryear>1979)
gen p9000 = (ryear<2000&ryear>1989)

by ccode_cov (ryear): egen mgpce_0010 = mean(gpce_joint) if p0010 // 2000-2010
by ccode_cov (ryear): egen mgpce_8010 = mean(gpce_joint) if p8010 // 1980 - 2010
by ccode_cov (ryear): egen mgpce_8000 = mean(gpce_joint) if p8000 // 1980 - 1999


* carry forward those that don't end in 2010
replace mgpce_8000=l.mgpce_8000 if l.mgpce_8000!=. & ryear< 2011

************ Table B-8 ************

* define 3 scenarios

gen pgpce_1 = mgpce_0010 // optimistic
gen pgpce_2 = mgpce_8010 // moderate
gen pgpce_3 = mgpce_8000 // pessimistic

* carry all forward
forv i=1(1)3 {
	replace pgpce_`i' = l.pgpce_`i' if pgpce_`i'==. & ryear>2010
}

* predict using loop over different pce peeds (i) and ginis (j,c)
forv i=1(1)3 {
	gen ln_mean_pce_`i' = ln_mean if ryear==2010
	replace ln_mean_pce_`i' = l.ln_mean_pce_`i'  + pgpce_`i' if ryear>2010
	replace ln_mean  = ln_mean_pce_`i' if ryear>2010

	local c = 1
	forv j=-0.005(0.005)0.005 {
		replace ln_gini = l.ln_gini + `j' if ryear>2010
		estimate restore hetglm
		predict double yhat_`i'_`c' if ryear>=2010
		local `c++'
	}
}

* aggregate to regions
tempfile regional
keep if ryear==2010 | ryear==2015 | ryear==2020 | ryear==2025 | ryear==2030
preserve

collapse (mean) yhat_* [aweight=pop_wb], by(regWB ryear)
	save `regional'
restore

collapse (mean) yhat_* [aweight=pop_wb], by(ryear)
append using `regional'

replace regWB = "Total" if regWB == ""

* merge in pop data per region
merge 1:1 regWB ryear using ./data/newWBpop
drop _merge

replace pop_wb =  pop_wb / 10^6 // in millions

forv i=1(1)3 {
	forv j=1(1)3 {
	gen poor_pop_`i'_`j' = yhat_`i'_`j'*pop_wb 
	*replace yhat_`i'_`j' = yhat_`i'_`j'*100
	}
}

* make headcount table with frmttable
preserve
	drop if ryear!=2030
	drop yhat_halfout
	mkmat yhat*, mat(A) rown(regWB)
	mkmat poor_pop_*, mat(B) rown(regWB)
restore

mat A = 100*A[1...,1...]

frmttable using  ./tables/Table_B_8.tex, tex s(A) sf(f) sd(2) replace landscape  a4 ///
	ctitles("", "", "Optimistic (2000-2010)", "", "", ///
	 "Central (1980-2010)" ,"", "", "Pessimistic (1980-2000)" ,"" \ ///
	 "", "-0.5% p.a.", "neutral", "0.5% p.a.", ///
	 "-0.5% p.a.", "neutral", "0.5% p.a.", "-0.5% p.a.", "neutral", "0.5% p.a.") ///
	rtitles(East Asia and Pacific \ Europe and Central Asia \ ///
	Latin America and Caribbean \ Middle East and North Africa \ ///
	South Asia \ Sub-Saharan Africa \ Total) hlines(101{0}11)

frmttable using  ./tables/Table_B_8.tex, tex s(B) sf(f) sd(2) append  landscape  a4 ///
	ctitles("", "", "Optimistic (2000-2010)", "", "", ///
	 "Central (1980-2010)" ,"", "", "Pessimistic (1980-2000)" ,"" \ ///
	 "", "-0.5% p.a.", "neutral", "0.5% p.a.", ///
	 "-0.5% p.a.", "neutral", "0.5% p.a.", "-0.5% p.a.", "neutral", "0.5% p.a.") ///
	rtitles(East Asia and Pacific \ Europe and Central Asia \ ///
	Latin America and Caribbean \ Middle East and North Africa \ ///
	South Asia \ Sub-Saharan Africa \ Total) hlines(101{0}11)

***********************************

*** data for figure 4 left panel, made in R

rename ryear year

keep if regWB=="Total"
append using ./data/povcal81to10

forv i=1(1)3 {
	forv j=1(1)3 {
	replace yhat_`i'_`j' = yhat_`i'_`j'*100
	replace yhat_`i'_`j' = Total if year == 2010
	}
}


sort year

reg Total year, r
predict ylin

saveold ./data/forRgraph_125d, replace version(12)

***********************************
*# EOF
