************** Parms **************
clear *
set more off
global path ~/replication_eer

************* Prelims *************

cd $path
use data/fullpanel0_march2013.dta

drop ryear
gen ryear = round(year)

drop if ryear<1981 | ryear>2010

** get PCE/pop from PWT71
merge m:1 ccode ryear using data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

* generate vars
xtset ccode_cov ryear

gen ln_mean = ln(mean)
gen ln_gini = ln(gini)
label variable ln_mean "$ \ln \bar{y}_{it} $"
label variable ln_gini "$ \ln G_{it} $"
gen ln_rcp = ln(rcp)

label variable d_mean "$ \Delta \ln \bar{y}_{it} $"
label variable d_gini "$ \Delta \ln G_{it} $"

* new shortfall definition, omit *-1, OLS will take case of signs
gen zmean = ln(l_mean/pl_200d) 
label variable zmean "$ \ln (\bar{y}_{i,t-1}/z) $"

replace l_mean = ln(l_mean)
replace l_gini = ln(l_gini)

label variable l_gini "$ \ln G_{i,t-1} $"

gen ln_h_200d = ln(h_200d)

encode regWB, gen(region)

************ Table B-1 ************

egen touse = rownonmiss(d_h_200d d_mean d_gini) // restrict to adiff sample

* (1) Within R+C ’97
xtreg ln_h_200d ln_mean ln_gini year  if touse, fe cluster(ccode_cov)

local eHy =  _b[ln_mean]
local eHg =  _b[ln_gini]
local eHy: dis %9.3f `eHy'
local eHg: dis %9.3f `eHg'

outreg2 using ./tables/Table_B_1.tex, replace eq(auto) nor2 noni  nocons drop(year) ///
	cti("OLS", "Within", "R + C '97") nonotes ///
	addstat("$ N $", e(N_g), "$ \bar{T} $", e(g_avg), "$ N \times \bar{T} $", e(N)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster 

* (2) Differences R+C ’97
reg d_h_200d d_mean d_gini , cluster(ccode_cov)

local eHy =  _b[d_mean]
local eHg =  _b[d_gini]
local eHy: dis %9.3f `eHy'
local eHg: dis %9.3f `eHg'

outreg2 using ./tables/Table_B_1.tex, append eq(auto) nor2 noni  nocons ///
	cti("OLS", "Differences", "R + C '97") nonotes ///
	addstat("$ N $", e(N_clust), "$ \bar{T} $", e(N)/e(N_clust), "$ N \times \bar{T} $", e(N)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster 

* (3) Differences Bourg. ’03
gen d_meanXl_gini = d_mean*l_gini
label var d_meanXl_gini "$ \Delta \ln \bar{y}_{it} \times \ln G_{i,t-1} $"
gen d_meanXzmean= d_mean*zmean
label var d_meanXzmean "$ \Delta \ln \bar{y}_{it} \times \ln (\bar{y}_{i,t-1}/z) $"
gen d_giniXl_gini = d_gini*l_gini
label var d_giniXl_gini "$ \Delta \ln G_{it} \times \ln G_{i,t-1} $"
gen d_giniXzmean= d_gini*zmean
label var d_giniXzmean "$ \Delta \ln G_{it} \times \ln (\bar{y}_{i,t-1}/z) $"

gen l_meanXl_gini = l_mean*l_gini
gen l_meanXzmean= l_mean*zmean
gen l_giniXl_gini = l_gini*l_gini
gen l_giniXzmean= l_gini*zmean

gen d_rcpXl_gini = d_rcp*l_gini
gen d_rcpXzmean= d_rcp*zmean

egen anymiss = rowmiss(d_h_200d d_mean d_gini d_rcp)

sum l_gini if !anymiss, meanonly
local gmean = `r(mean)'
sum zmean if !anymiss, meanonly
local zmean = `r(mean)'

reg d_h_200d d_mean d_meanXl_gini d_meanXzmean d_gini d_giniXl_gini d_giniXzmean, cluster(ccode_cov)
	 
gen APE1 = _b[d_mean] + _b[d_meanXl_gini]*l_gini + _b[d_meanXzmean] * zmean
sum APE1, meanonly
local eHy: dis %9.3f `r(mean)'

gen APE2 = _b[d_gini] + _b[d_giniXl_gini]*l_gini + _b[d_giniXzmean] * zmean
sum APE2, meanonly
local eHg: dis %9.3f `r(mean)'

drop APE1 APE2

outreg2 using ./tables/Table_B_1.tex, append eq(auto) nor2 noni  nocons ///
	cti("OLS", "Differences", "Bourg. '03") nonotes ///
	addstat("$ N $", e(N_clust), "$ \bar{T} $", e(N)/e(N_clust), "$ N \times \bar{T} $", e(N)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster 

* (4) Differences R+C ’97
ivreg2 d_h_200d (d_mean d_gini = d_rcp l_rcp l_mean l_gini) , ///
	cluster(ccode_cov) small gmm2s 
	
local eHy =  _b[d_mean]
local eHg =  _b[d_gini]
local eHy: dis %9.3f `eHy'
local eHg: dis %9.3f `eHg'
	
outreg2 using ./tables/Table_B_1.tex, append eq(auto) nor2 noni  nocons ///
	cti("GMM", "Differences", "R + C '97") nonotes ///
	addstat("$ N $", e(N_clust), "$ \bar{T} $", e(N)/e(N_clust), ///
	 "$ N \times \bar{T} $", e(N), "Hansen's $ J $ (p-val.)",  e(jp)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster 

* (5) Differences Bourg. ’03	 
ivreg2 d_h_200d (d_mean d_meanXl_gini d_meanXzmean d_gini d_giniXl_gini d_giniXzmean ///
	=  l_meanXl_gini l_meanXzmean l_giniXl_gini ///
	 d_rcp l_rcp d_rcpXl_gini d_rcpXzmean l_gini zmean), cluster(ccode_cov) small gmm2s 	first

gen APE1 = _b[d_mean] + _b[d_meanXl_gini]*l_gini + _b[d_meanXzmean] * zmean
sum APE1
local eHy: dis %9.3f `r(mean)'

gen APE2 = _b[d_gini] + _b[d_giniXl_gini]*l_gini + _b[d_giniXzmean] * zmean
sum APE2
local eHg: dis %9.3f `r(mean)'

drop APE1 APE2

outreg2 using ./tables/Table_B_1.tex, append eq(auto) nor2 noni  nocons ///
	cti("GMM", "Differences", "Bourg. '03") nonotes ///
	addstat("$ N $", e(N_clust), "$ \bar{T} $", e(N)/e(N_clust), ///
	 "$ N \times \bar{T} $", e(N), "Hansen's $ J $ (p-val.)",  e(jp)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster 
	 
* (4) Differences K+V ’97
ivreg2 d_h_200d (d_mean d_meanXl_gini d_meanXzmean d_gini d_giniXl_gini d_giniXzmean ///
	=  l_meanXl_gini l_meanXzmean l_giniXl_gini ///
	 d_rcp l_rcp d_rcpXl_gini d_rcpXzmean) l_gini zmean, cluster(ccode_cov) small gmm2s 
	 
gen APE1 = _b[d_mean] + _b[d_meanXl_gini]*l_gini + _b[d_meanXzmean] * zmean 
sum APE1
local eHy: dis %9.3f `r(mean)'

gen APE2 = _b[d_gini] + _b[d_giniXl_gini]*l_gini + _b[d_giniXzmean] * zmean 
sum APE2
local eHg: dis %9.3f `r(mean)'

drop APE1 APE2

outreg2 using ./tables/Table_B_1.tex, append eq(auto) nor2 noni  nocons ///
	cti("GMM", "Differences", "K + V '07") nonotes ///
	addstat("$ N $", e(N_clust), "$ \bar{T} $", e(N)/e(N_clust), ///
	 "$ N \times \bar{T} $", e(N), "Hansen's $ J $ (p-val.)",  e(jp)) ///
	 addtext("$ \bar{\hat{\varepsilon}}^{H\bar{y}} $", `eHy', ///
	 "$ \bar{\hat{\varepsilon}}^{HG} $", `eHg') ///
	 noobs label dec(3) noaster tex(frag)

***********************************
*# EOF
