************** Parms **************
clear *
set more off
global path ~/replication_eer
global bsreps 999
parallel setclusters 10, force // here we assume 10 cpus

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)
* ssc install parallel, replace
* mata mata mlib index

************* Prelims *************

cd $path
use data/fullpanel0_march2013.dta

drop ryear
gen ryear = round(year)

* restrict sample to best coverage
drop if ryear<1981 | ryear>2010

* get PCE per capita from PWT71

merge m:1 ccode ryear using data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

* generate vars
xtset ccode_cov ryear

gen ln_mean = ln(mean)
gen ln_gini = ln(gini)
gen ln_rcp = ln(rcp)

label var ln_mean "$ \ln \bar{y}_{it} $"
label var ln_gini "$ \ln G_{it} $"
label var h_200d "$ H_{it} $"
label var ln_rcp "$ \ln PCE^P_{it} $"

encode regWB, gen(region) //region dummies

************ Table B-2 ************

**** clean for first models: balanced case (ignore unbalancedness)

egen anymiss = rowmiss(h_200d ln_mean ln_gini)
drop if anymiss

*** final data starts here

gen rcp12 = rcp/12


bys ccode_cov (ryear): gen Ti = _N 
tab Ti if ~anymiss, gen(Ti_)

tab stype if ~anymiss, gen(S_)

* generate componets of the test
gen sigma = sqrt(2)*invnormal(gini/2 + 1/2)
gen sigma2 = sigma^2
gen ln_sigma2 = log(sigma2)

label var sigma2 "$ \sigma_{it}^2 $"
label var ln_sigma2 "$ \log \sigma_{it}^2 $"


bys ccode_cov (ryear): egen sigma2_bar = mean(sigma2)
bys ccode_cov (ryear): egen ln_sigma2_bar = mean(ln_sigma2)


bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
forv i = 1981(1)2010 {
	gen y_`i' =  (ryear==`i') 
	bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
}


* GLM
fhetprob h_200d  ln_mean ln_mean_bar sigma2 sigma2_bar y_1981-yb_2009 S_2-S_4 Sb_* if Ti>1, ///
	het(ln_sigma2) vce(cluster ccode_cov)

test (ln_mean = -1) (sigma2 = 1/2) (ln_sigma2 = 1/2) 
local joint_p = r(p)


	
margins, dydx(ln_mean) nose

predictnl  double scale=normalden(xb()) if e(sample) 
sum scale
local scale = r(mean)

predict double yhat if e(sample)
corr yhat h_200d
local r2 = r(rho)^2
gen se = (h_200d - yhat)^2 
sum se, mean
local rmse = sqrt(r(mean))
 
outreg2 using ./tables/Table_B_2.tex, replace keep(ln_mean sigma2 ln_sigma2) eqkeep(h_200d) noobs ///
	addtext("CRE - Corr. Rand. Effects", Yes, ///
	"Survey type dummies", Yes, ///
	"Time dummies", Yes, ///
	"Panel size dummies", No, ///
	"Panel size $ \times $ CRE", No, ///
	"Variance equation", Yes ) /// 
	addstat(Joint test (p-value), `joint_p', ///
	Scale Factor, `scale', ///
	$ N \times \bar{T} $, e(N), ///
	$ N $, e(N_clust), $ pseudo-R^2 $, `r2', $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
	nocons label eq(auto) ct("$ H_{it} $") noaster nonotes dec(3)
	
margins, dydx(ln_mean)  post

outreg2 using ./tables/Table_B_2.tex, append keep(ln_mean ln_gini) noobs ///
	nocons label eq(auto) ct("APEs") noaster nonotes dec(3)
	
* flexible unbalanced


fhetprob  h_200d ln_mean sigma2 ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.sigma2_bar ///
	y_1981-yb_2009  S_2-S_4 Sb_* if Ti>1, het(ln_sigma2 ib(last).Ti  ib(last).Ti##c.ln_sigma2_bar ) vce(cluster ccode_cov)

test (ln_mean = -1) (sigma2 = 1/2) (ln_sigma2 = 1/2) 
local joint_p = r(p)
	
cap drop scale
predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
sum scale
local scale = r(mean)

cap drop yhat 
cap drop se
predict double yhat if e(sample)
corr yhat h_200d
local r2 = r(rho)^2
gen se = (h_200d - yhat)^2 
sum se, mean
local rmse = sqrt(r(mean))
dis `rmse'

outreg2 using ./tables/Table_B_2.tex, append keep(ln_mean sigma2 ln_sigma2) eqkeep(h_200d) noobs ///
	addtext("CRE - Corr. Rand. Effects", Yes, ///
	"Survey type dummies", Yes, ///
	"Time dummies", Yes, ///
	"Panel size dummies", Yes, ///
	"Panel size $ \times $ CRE", Yes, ///
	"Variance equation", Yes ) /// 
	addstat(Joint test (p-value), `joint_p', ///
	Scale Factor, `scale', ///
	$ N \times \bar{T} $, e(N), ///
	$ N $, e(N_clust), $ pseudo-R^2 $, `r2', $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
	nocons label eq(auto) ct("$ H_{it} $")   noaster dec(3)

margins, dydx(ln_mean)  post

outreg2 using ./tables/Table_B_2.tex, append keep(ln_mean sigma2) noobs ///
	nocons label eq(auto) ct("APEs") noaster nonotes dec(3)


* accounting for measurement error

cap drop anymiss ln_mean_bar ln_gini_bar y_* yb_* Ti Ti_* S_* Sb_* sigma* ln_sigma2*
egen anymiss = rowmiss(h_200d ln_mean ln_gini ln_rcp)
drop if anymiss

bys ccode_cov (ryear): gen Ti = _N 
tab Ti, gen(T_) 

tab stype, gen(S_)

* generate componets of the test
gen sigma = sqrt(2)*invnormal(gini/2 + 1/2)
gen sigma2 = sigma^2
gen ln_sigma2 = log(sigma2)

label var sigma2 "$ \sigma_{it}^2 $"
label var ln_sigma2 "$ \log \sigma_{it}^2 $"


bys ccode_cov (ryear): egen sigma2_bar = mean(sigma2)
bys ccode_cov (ryear): egen ln_sigma2_bar = mean(ln_sigma2)


bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini)
bys ccode_cov (ryear): egen ln_rcp_bar = mean(ln_rcp)

bys ccode_cov (ryear): egen Sb_2 = mean(S_2)
bys ccode_cov (ryear): egen Sb_3 = mean(S_3)
bys ccode_cov (ryear): egen Sb_4 = mean(S_4)

forv i = 1981(1)2010 {
	gen y_`i' =  (ryear==`i')
	bys ccode_cov (ryear): egen yb_`i' = mean(y_`i')
}

* control function: 1st step
reg ln_mean ln_rcp sigma2 ib(last).Ti##c.ln_rcp_bar ib(last).Ti##c.sigma2_bar ///
		y_1981-yb_2009 S_2-S_4 Sb_* if Ti>1, vce(cluster ccode_cov)

predict v2hat if e(sample), resid
label var v2hat "$ \hat{\nu}_{it} $"

* control function: 2nd step
fhetprob  h_200d ln_mean sigma2 v2hat  ib(last).Ti##c.ln_rcp_bar ib(last).Ti##c.sigma2_bar ///
	y_1981-yb_2009  S_2-S_4 Sb_* if Ti>1, het(ln_sigma2 ib(last).Ti  ib(last).Ti##c.ln_sigma2_bar ) vce(cluster ccode_cov) iter(100)

estimates store varfhet
test v2hat

cap drop scale
predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
sum scale
local scale = r(mean)	

cap drop yhat se
predict double yhat if e(sample)
corr yhat h_200d
local r2 = r(rho)^2
gen se = (h_200d - yhat)^2 
sum se, mean
local rmse = sqrt(r(mean))
local aic = e(aic)
local ll = e(ll)

cap program drop twostep_boot

program twostep_boot, eclass
version 12.0
tempname bb v2h meanbar conv
	* control function: 1st step
	reg ln_mean ln_rcp sigma2 ib(last).Ti##c.ln_rcp_bar ib(last).Ti##c.sigma2_bar ///
		y_1981-yb_2009 S_2-S_4 Sb_* if Ti>1
	predict `v2h', resid
	
	bys newid (ryear): egen `meanbar' = mean(ln_mean) if e(sample)

	* control function: 2nd step, set iter 100 to unjam too long bs iterations
	fhetprob  h_200d ln_mean sigma2 `v2h' ib(last).Ti##c.`meanbar' ib(last).Ti##c.ln_rcp_bar ib(last).Ti##c.sigma2_bar ///
	y_1981-yb_2009  S_2-S_4 Sb_* if Ti>1, het(ln_sigma2 ib(last).Ti  ib(last).Ti##c.ln_sigma2_bar) iter(100)

	scalar `conv' = e(converged)

	mat `bb' = e(b)
	mat `bb' = `bb'[1,1..3],_b[lnsigma2:ln_sigma2]	
	
	margins, dydx(ln_mean) nose
	mat `bb' = `bb',r(b)
	mat coln `bb' =  h_200d:ln_mean h_200d:sigma2 h_200d:v2hat h_200d:ln_sigma2 APEs:ln_mean
	ereturn post `bb', depn(h_200d)
	ereturn scalar converged =`conv'

end

preserve

xtset, clear

drop if Ti==1 //really needed? yes

parallel bs, reps(`=$bsreps') ///
 seeds(10203 20301 30201 20103 40506 50604 60504 50406 70809 80907) ///
 cluster(ccode_cov) idcluster(newid) nowarn reject(e(converged)==0): twostep_boot

xtset ccode_cov ryear


test (ln_mean = -1) (sigma2 = 1/2) (ln_sigma2 = 1/2) 
local joint_p = r(p)

outreg2 using ./tables/Table_B_2.tex, append eqkeep(h_200d) keep(ln_mean sigma2 ln_sigma2 v2hat) noobs ///
	addtext("CRE - Corr. Rand. Effects", Yes, ///
	"Survey type dummies", Yes, ///
	"Time dummies", Yes, ///
	"Panel size dummies", Yes, ///
	"Panel size $ \times $ CRE", Yes, ///
	"Variance equation", Yes ) /// 
	addstat(Joint test (p-value), `joint_p', ///
	Scale Factor, `scale', ///
	$ N \times \bar{T} $, e(N), ///
	$ N $, e(N_clust), $ pseudo-R^2 $, `r2', $ \ln \mathcal{L} $ , `ll', $ \sqrt{MSE} $, `rmse') ///
	nocons label ct("$ H_{it} $") noaster dec(3)
	

outreg2 using ./tables/Table_B_2.tex, append ct("APEs") eqkeep(APEs) keep(ln_mean) noobs ///
	nocons label noaster nonotes tex(frag) dec(3)
	
restore

***********************************
*% EOF
