************** Parms **************
clear *
set more off
global path ~/replication_eer

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)

************* Prelims *************

cd $path
use data/fullpanel0_march2013.dta


drop ryear
gen ryear = round(year)

drop if ryear<1981 | ryear>2010

xtset ccode_cov ryear

************ Table B-1 ************

label var exconst "Executive Constraints"

merge m:1 ccode using data/ww2003, keepusing(start tmpstart1 tmpstart2 tmpend1 tmpend2 wwmax)
gen inww2003=(_merge==3)
drop if _merge==2
drop _merge

// generate econ lib data:
gen libtrade = 0 if inww2003 & ryear<2002
replace libtrade = 1 if ryear>=start & ryear<=wwmax
replace libtrade = 1 if ryear>=tmpstart1 & ryear<=tmpend1
replace libtrade = 1 if ryear>=tmpstart2 & ryear<=tmpend2
label var libtrade "Trade Openness"

gen libtradestart = 0 if inww2003 & ryear<2002
replace libtradestart = 1 if year==start
label var libtradestart "Start Openness"


merge 1:1 ccode ryear using data/FinStructure2013.dta, keepusing(pcrdbofgdp)
drop if _merge==2
drop _merge

rename pcrdbofgdp pcredit 
label var pcredit "Private Credit / GDP"
replace pcredit = pcredit/100
sum pcredit

merge 1:1 ccode ryear using data/bl2013.dta
drop if _merge==2
drop _merge

label var sch_all_int "Year of Schooling"

*** end merges start code
gen ln_mean = ln(mean)
gen ln_gini = ln(gini)

label var ln_mean "$ \ln \bar{y}_{it} $"
label var ln_gini "$ \ln G_{it} $"
label var h_200d "$ H_{it} $"

encode regWB, gen(region) //region dummies

*** (1) INSTITUTIONS
preserve
	egen anymiss = rowmiss(h_200d ln_mean ln_gini sch_all_int)
	drop if anymiss

	bys ccode_cov (ryear): gen Ti = _N 
	tab Ti if ~anymiss, gen(Ti_)

	tab stype if ~anymiss, gen(S_)

	bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
	bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
	bys ccode_cov (ryear): egen exconst_bar = mean(exconst) 
	bys ccode_cov (ryear): egen sch_all_int_bar = mean(sch_all_int) 
	bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
	bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
	bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
	qui sum ryear
	forv i = 1981(1)`r(max)' {
		gen y_`i' =  (ryear==`i') 
		bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
	}

		
	* flexible unbalanced
	fhetprob h_200d  ln_mean ln_gini exconst ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
		ib(last).Ti##c.exconst_bar y_1982-yb_2010 S_2-S_4 Sb_* if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov)	
	
	margins, eydx(ln_mean ln_gini exconst) 	nose
	cap drop scale
	predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
	sum scale
	local scale = r(mean)

	cap drop yhat 
	cap drop se
	predict double yhat if e(sample)
	gen se = (h_200d - yhat)^2 
	sum se, mean
	local rmse = sqrt(r(mean))
	dis `rmse'

	outreg2 using ./tables/Table_B_3.tex, replace keep(ln_mean ln_gini exconst) noobs ///
		addtext(CRE - $ \mathbf{\bar{x}}_i $, Yes, ///
		Welfare type dummies - $ \eta_{s} $, Yes, ///
		Time dummies - $ \lambda_{t} $, Yes, ///
		Panel size dummies - $ g_{ir} $, Yes, ///
		Panel size $ \times $ CRE - $ g_{ir} \times \mathbf{\bar{x}}_i $, Yes, ///
		Variance equation - $ \mathbf{z}_{it}\boldsymbol\gamma $, Yes ) /// 
		addstat(Scale Factor, `scale', ///
		$ N \times \bar{T} $, e(N), ///
		$ N $, e(N_clust), AIC, e(aic), $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
		nocons label eq(auto) ct("$ H_{it} $")   noaster bdec(3)
	margins, dydx(ln_mean ln_gini exconst) post	
		
	outreg2 using ./tables/Table_B_3.tex, append ct("APEs") eqkeep(APEs) ///
		keep(ln_mean ln_gini exconst) noobs ///
		nocons label noaster nonotes bdec(3)
restore

*** (2) SCHOOLING
preserve
	egen anymiss = rowmiss(h_200d ln_mean ln_gini sch_all_int)
	drop if anymiss

	bys ccode_cov (ryear): gen Ti = _N 
	tab Ti if ~anymiss, gen(Ti_)

	tab stype if ~anymiss, gen(S_)

	bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
	bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
	bys ccode_cov (ryear): egen exconst_bar = mean(exconst) 
	bys ccode_cov (ryear): egen sch_all_int_bar = mean(sch_all_int) 
	bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
	bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
	bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
	qui sum ryear
	forv i = 1981(1)`r(max)' {
		gen y_`i' =  (ryear==`i') 
		bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
	}

		
	* flexible unbalanced
	fhetprob h_200d  ln_mean ln_gini sch_all_int ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
		ib(last).Ti##c.sch_all_int_bar y_1982-yb_2010 S_2-S_4 Sb_* if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov)	
	margins, eydx(ln_mean ln_gini sch_all_int) 	nose
	cap drop scale
	predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
	sum scale
	local scale = r(mean)

	cap drop yhat 
	cap drop se
	predict double yhat if e(sample)
	gen se = (h_200d - yhat)^2 
	sum se, mean
	local rmse = sqrt(r(mean))
	dis `rmse'

	outreg2 using ./tables/Table_B_3.tex, append keep(ln_mean ln_gini sch_all_int) noobs ///
		addtext(CRE - $ \mathbf{\bar{x}}_i $, Yes, ///
		Welfare type dummies - $ \eta_{s} $, Yes, ///
		Time dummies - $ \lambda_{t} $, Yes, ///
		Panel size dummies - $ g_{ir} $, Yes, ///
		Panel size $ \times $ CRE - $ g_{ir} \times \mathbf{\bar{x}}_i $, Yes, ///
		Variance equation - $ \mathbf{z}_{it}\boldsymbol\gamma $, Yes ) /// 
		addstat(Scale Factor, `scale', ///
		$ N \times \bar{T} $, e(N), ///
		$ N $, e(N_clust), AIC, e(aic), $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
		nocons label eq(auto) ct("$ H_{it} $")   noaster  bdec(3)
	margins, dydx(ln_mean ln_gini sch_all_int) post	
		
	outreg2 using ./tables/Table_B_3.tex, append ct("APEs") eqkeep(APEs) ///
		keep(ln_mean ln_gini sch_all_int) noobs ///
		nocons label noaster nonotes bdec(3)
restore


*** (3) CREDIT
preserve
	egen anymiss = rowmiss(h_200d ln_mean ln_gini pcredit)
	drop if anymiss

	bys ccode_cov (ryear): gen Ti = _N 
	tab Ti if ~anymiss, gen(Ti_)

	tab stype if ~anymiss, gen(S_)

	bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
	bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
	bys ccode_cov (ryear): egen exconst_bar = mean(exconst) 
	bys ccode_cov (ryear): egen pcredit_bar = mean(pcredit) 
	bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
	bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
	bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
	qui sum ryear
	forv i = 1981(1)`r(max)' {
		gen y_`i' =  (ryear==`i') 
		bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
	}

		
	* flexible unbalanced
	fhetprob h_200d  ln_mean ln_gini pcredit ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
		ib(last).Ti##c.pcredit_bar y_1982-yb_2010 S_2-S_4 Sb_* if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov)	
	margins, eydx(ln_mean ln_gini pcredit) 	nose

	cap drop scale
	predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
	sum scale
	local scale = r(mean)

	cap drop yhat 
	cap drop se
	predict double yhat if e(sample)
	gen se = (h_200d - yhat)^2 
	sum se, mean
	local rmse = sqrt(r(mean))
	dis `rmse'

	outreg2 using ./tables/Table_B_3.tex, append keep(ln_mean ln_gini pcredit) noobs ///
		addtext(CRE - $ \mathbf{\bar{x}}_i $, Yes, ///
		Welfare type dummies - $ \eta_{s} $, Yes, ///
		Time dummies - $ \lambda_{t} $, Yes, ///
		Panel size dummies - $ g_{ir} $, Yes, ///
		Panel size $ \times $ CRE - $ g_{ir} \times \mathbf{\bar{x}}_i $, Yes, ///
		Variance equation - $ \mathbf{z}_{it}\boldsymbol\gamma $, Yes ) /// 
		addstat(Scale Factor, `scale', ///
		$ N \times \bar{T} $, e(N), ///
		$ N $, e(N_clust), AIC, e(aic), $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
		nocons label eq(auto) ct("$ H_{it} $")   noaster bdec(3)
	margins, dydx(ln_mean ln_gini pcredit) post	
		
	outreg2 using ./tables/Table_B_3.tex, append ct("APEs") eqkeep(APEs) ///
		keep(ln_mean ln_gini pcredit) noobs ///
		bdec(3) nocons label noaster nonotes
restore

*** (4) LIBTRADE
preserve
	egen anymiss = rowmiss(h_200d ln_mean ln_gini libtrade)
	drop if anymiss

	bys ccode_cov (ryear): gen Ti = _N 
	tab Ti if ~anymiss, gen(Ti_)

	tab stype if ~anymiss, gen(S_)

	bys ccode_cov (ryear): egen ln_mean_bar = mean(ln_mean)
	bys ccode_cov (ryear): egen ln_gini_bar = mean(ln_gini) 
	bys ccode_cov (ryear): egen exconst_bar = mean(exconst) 
	bys ccode_cov (ryear): egen libtrade_bar = mean(libtrade) 
	bys ccode_cov (ryear): egen Sb_2 = mean(S_2) 
	bys ccode_cov (ryear): egen Sb_3 = mean(S_3) 
	bys ccode_cov (ryear): egen Sb_4 = mean(S_4) 
	qui sum ryear
	forv i = 1981(1)`r(max)' {
		gen y_`i' =  (ryear==`i') 
		bys ccode_cov (ryear): egen yb_`i' = mean(y_`i') 
	}

		
	* flexible unbalanced
	fhetprob h_200d  ln_mean ln_gini libtrade ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
		ib(last).Ti##c.libtrade_bar y_1982-yb_2001 S_2-S_4 Sb_* if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov)	
	margins, eydx(ln_mean ln_gini libtrade) 	nose

	cap drop scale
	predictnl double scale=normalden(xb(#1)/exp(xb(#2)))*exp(-xb(#2)) if e(sample) 
	sum scale
	local scale = r(mean)

	cap drop yhat 
	cap drop se
	predict double yhat if e(sample)
	gen se = (h_200d - yhat)^2 
	sum se, mean
	local rmse = sqrt(r(mean))
	dis `rmse'

	outreg2 using ./tables/Table_B_3.tex, append keep(ln_mean ln_gini libtrade) noobs ///
		addtext(CRE - $ \mathbf{\bar{x}}_i $, Yes, ///
		Welfare type dummies - $ \eta_{s} $, Yes, ///
		Time dummies - $ \lambda_{t} $, Yes, ///
		Panel size dummies - $ g_{ir} $, Yes, ///
		Panel size $ \times $ CRE - $ g_{ir} \times \mathbf{\bar{x}}_i $, Yes, ///
		Variance equation - $ \mathbf{z}_{it}\boldsymbol\gamma $, Yes ) /// 
		addstat(Scale Factor, `scale', ///
		$ N \times \bar{T} $, e(N), ///
		$ N $, e(N_clust), AIC, e(aic), $ \ln \mathcal{L} $ , e(ll), $ \sqrt{MSE} $, `rmse') ///
		nocons label eq(auto) ct("$ H_{it} $")   noaster bdec(3)
	margins, dydx(ln_mean ln_gini libtrade) post	
		
	outreg2 using ./tables/Table_B_3.tex, append ct("APEs") eqkeep(APEs) ///
		keep(ln_mean ln_gini libtrade) noobs ///
		nocons label noaster nonotes bdec(3) tex(frag)
restore

***********************************
*% EOF
