************** Parms **************
clear *
set more off
global path ~/replication_eer

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)

************* Prelims *************

cd $path
use ./data/fullpanel0_march2013.dta
drop ryear
gen ryear = round(year)

duplicates report ccode_cov ryear
duplicates list ccode_cov ryear

drop if ryear<1981 | ryear>2010

** get PCE/pop from PWT71

merge m:1 ccode ryear using ./data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

* generate vars
xtset ccode_cov ryear

gen ln_mean = ln(mean)
gen ln_gini = ln(gini)
gen ln_rcp = ln(rcp)

label var ln_mean "$ \ln \bar{y}_{it} $"
label var ln_gini "$ \ln G_{it} $"
label var h_200d "$ H_{it} $"
label var ln_rcp "$ \ln PCE^P_{it} $"

encode regWB, gen(region) //region dummies

************ Table B-4 ************

**** clean for first models: balanced case (ignore unbalancedness)

egen anymiss = rowmiss(h_200d ln_mean ln_gini)
drop if anymiss

*** final data starts here

*  time groups
cap drop ygroups
recode ryear  (1980/1995=1 "early 90s") ///
	(1995/2000=2 "late 90s") (2000/2005=3 "early 00s") ///
	(2005/2010=4 "late 00s"), gen(ygroups)
tab ygroups

levelsof ygroups, local(klevs)
local k : list sizeof local(klevs)
mat results = J(6,1,.)
mat world = J(1,1,.)
encode regWB, gen(region2)

* Fit models and calculate errors.
        
forvalues i=2/`k' {
	di "`i'"

	preserve
		bys ccode_cov (ryear): gen x_Ti = _N  if ygroups<`i'
		bys ccode_cov (ryear): egen Ti = max(x_Ti) 

		tab Ti if ~anymiss, gen(Ti_)

		tab stype if ~anymiss, gen(S_)

		bys ccode_cov (ryear): egen x_ln_mean_bar = mean(ln_mean) if ygroups<`i'
		bys ccode_cov (ryear): egen x_ln_gini_bar = mean(ln_gini) if ygroups<`i'
		bys ccode_cov (ryear): egen x_Sb_2 = mean(S_2) if ygroups<`i'
		bys ccode_cov (ryear): egen x_Sb_3 = mean(S_3) if ygroups<`i'
		bys ccode_cov (ryear): egen x_Sb_4 = mean(S_4) if ygroups<`i'

		bys ccode_cov (ryear): egen ln_mean_bar = max(x_ln_mean_bar) 
		bys ccode_cov (ryear): egen ln_gini_bar = max(x_ln_gini_bar) 
		bys ccode_cov (ryear): egen Sb_2 = max(x_Sb_2) 
		bys ccode_cov (ryear): egen Sb_3 = max(x_Sb_3)
		bys ccode_cov (ryear): egen Sb_4 = max(x_Sb_4) 

		forv j = 1981(1)2010 {
			gen y_`j' =  (ryear==`j') 
			bys ccode_cov (ryear): egen x_yb_`j' = mean(y_`j') if ygroups<`i'
			bys ccode_cov (ryear): egen yb_`j' = max(x_yb_`j') 
		}

		drop x_*


		* flexible unbalanced
		qui fhetprob h_200d  ln_mean ln_gini ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
			y_1981-yb_2009 S_2-S_4 Sb_*  if Ti>1 & ygroups<`i', het(ib(last).Ti) vce(cluster ccode_cov)
			
		* ln_gini ib(last).Ti##c.ln_gini_bar 
			
		predict y_hat_in if ygroups==`i'

		dis as error "here"

		mean y_hat_in [aweight=pop], over(region2) nol
		mat results=results,e(b)'

		mean y_hat_in [aweight=pop], nol
		mat world=world,e(b)'

		gen H_true = h_200d if ygroups==`i'

		mean H_true [aweight=pop], over(region2) nol
		mat results=results,e(b)'

		mean H_true [aweight=pop], nol
		mat world=world,e(b)'

		tab region2 if ygroups==`i' 
	restore

	* rmse from this data


}

mat li results

mata
	T = st_matrix("results")
	T=T[,6..7]
	W = st_matrix("world")
	W=W[,6..7]
	T = T\W
	T = T, abs(T[,1] - T[,2]) 

	st_matrix("T", T)
end


frmttable using ./tables/Table_B_4.tex, store(tab1) s(T) ///
	var sf(f) sd(5)  ctitles("Region", "Predicted H", "True H", "Absolute Error") replace ///
	rtitles("East Asia and Pacific"\ "Eastern Europe and Central Asia" \ ///
	"Latin America and Caribbean" \ "Middle East and North Africa" \ ///
	"South Asia" \ "Sub-Saharan Africa" \ "Developing world") tex fragment

***********************************
*% EOF
