************** Parms **************
clear *
set more off
global path ~/replication_eer

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)

************* Prelims *************

cd $path
use data/fullpanel0_march2013.dta, clear
do ./includes/xtcross.do

drop ryear
gen ryear = round(year)

duplicates report ccode_cov ryear
duplicates list ccode_cov ryear

drop if ryear<1981 | ryear>2010

** get PCE/pop from PWT71

merge m:1 ccode ryear using data/pwt71_w_consumption2.dta
drop if _merge==2
xtset ccode_cov ryear
drop _merge

* generate vars
xtset ccode_cov ryear

gen ln_mean = ln(mean)
gen ln_gini = ln(gini)
gen ln_rcp = ln(rcp)

label var ln_mean "$ \ln \bar{y}_{it} $"
label var ln_gini "$ \ln G_{it} $"
label var h_200d "$ H_{it} $"
label var ln_rcp "$ \ln PCE^P_{it} $"

************ Table B-5 ************

*** clean

egen anymiss = rowmiss(h_200d ln_mean ln_gini)
drop if anymiss

*** final data starts here

bys ccode_cov (ryear): gen Ti = _N 

set seed 20202
xtcross fhetprob h_200d  ln_mean ln_gini ib(last).Ti##c.ln_mean_bar ib(last).Ti##c.ln_gini_bar ///
	y_1981-yb_2009 S_2-S_4 Sb_*  if Ti>1, het(ib(last).Ti) vce(cluster ccode_cov) k(10)  

mat li r(est)
mata
	T = st_matrix("r(est)")
	R = T[,1] 
	R2 = R:*R
	R = R\sqrt(mean(R2))
	B = (809:-T[,4])/809
	T = T[,2..3], B, T[,4]/809
	T = T\mean(T)
	R = R, T
	st_matrix("R", R)
end

mat li R

frmttable using ./tables/Table_B_5.tex, store(tab1) s(R) ///
	var sf(f) sd(5,5,3,3,3)  ctitles("Fold", "RMSE", "MAE", "R-Squared", "Perc. Train", "Perc. Test") replace ///
	rtitles("1" \ "2"\ "3"\ "4"\ "5"\ "6"\ "7"\ "8"\ "9"\ "10"\ "CV_10") tex fragment

***********************************
*% EOF
