************** Parms **************
clear *
set more off
global path ~/replication_eer

************** Progs **************

* net install fhetprob, from(http://www.richard-bluhm.com/stata/)

************* Prelims *************

cd $path

set seed 20202
local R = 1000
local N = 100
local t = 10
local T = 1000 // number of bernoulli trials


************ Table C-2 ************

cap postclose buffer
postfile buffer e_Hybar n_Hybar e_Hybar_1 n_Hybar_1 ///
		e_Hybar_2 n_Hybar_2 e_Hybar_3 n_Hybar_3 ///
		e_Hybar_4 n_Hybar_4 e_Hybar_5 n_Hybar_5 ///
		hat_e_Hybar_glm hat_n_Hybar_glm hat_e_Hybar_glm_1 hat_n_Hybar_glm_1 ///
		hat_e_Hybar_glm_2 hat_n_Hybar_glm_2 hat_e_Hybar_glm_3 hat_n_Hybar_glm_3 ///
		hat_e_Hybar_glm_4 hat_n_Hybar_glm_4 hat_e_Hybar_glm_5 hat_n_Hybar_glm_5 ///
		hat_e_Hybar_ols hat_n_Hybar_ols hat_e_Hybar_ols_1 hat_n_Hybar_ols_1 ///
		hat_e_Hybar_ols_2 hat_n_Hybar_ols_2 hat_e_Hybar_ols_3 hat_n_Hybar_ols_3 ///
		hat_e_Hybar_ols_4 hat_n_Hybar_ols_4 hat_e_Hybar_ols_5 hat_n_Hybar_ols_5 ///
		using ./data/mcs, replace

forvalues i=1/`R' {

	display "i is now `i'"

	qui {

	drop _all
	
	set obs `N' 
	gen id = _n
	expand `t'
	bys id: gen t = _n

	* set poverty line
	gen z = 60.83
	
	* draw means
	gen mu = 4.75 + runiform(-1.75,1.75)

	* generate sigma
	gen sigma = 0.8 + runiform(-.25,.25)

	* generate incomes
	gen ybar = exp(mu + sigma^2 / 2)

	sum ybar

	* generate ginis --> could reverse this to sigmas
	gen gini = 2*normal(sigma/sqrt(2)) -1
	sum gini


	* generate headcounts
	gen  H = normal( -log(ybar/z)/sigma + 1/2 * sigma )
	gen Hxb = -log(ybar/z)/sigma + 1/2 * sigma

	* generate actual elasticities
	gen e_Hybar = -1/sigma *  [ normalden(Hxb)/normal(Hxb)  ]

	* generate actual semi-elasticities
	gen n_Hybar = -1/sigma * normalden(Hxb)
	drop Hxb
		
	* draw from binomial with pr H
	gen y =  rbinomial(`T',H)/`T'

	*convert to logs
	gen log_ybar = log(ybar)
	gen log_gini = log(gini)

	xtset id t
	bys id (t): egen log_ybar_mean =  mean(log_ybar)
	bys id (t): egen log_gini_mean =  mean(log_gini)
	
	*** truth for predefined ybars
	sum ybar, d
	local percentiles r(p5) r(p25)  r(p50)  r(p75)  r(p95)
	local j = 1
	foreach x of local percentiles   {
	di `x'
	gen Hxb_`j' = -log(`x'/z)/sigma + 1/2 * sigma

	* generate actual elasticities
	gen e_Hybar_`j' = -1/sigma *  [ normalden(Hxb)/normal(Hxb)  ]

	* generate actual semi-elasticities
	gen n_Hybar_`j' = -1/sigma * normalden(Hxb)
	drop  Hxb_`j'
	local `j++'
	 }

	*** our model
	glm y log_ybar log_gini log_ybar_mean log_gini_mean, fam(bin) link(probit)	vce(cluster id)
	estimates store fprob
	* this is the trick, we want margins at different values
	margins, dydx(log_ybar) post nose  
	local hat_n_Hybar_glm = _b[log_ybar]
	estimates restore fprob
	margins, eydx(log_ybar) post nose  
	local hat_e_Hybar_glm = _b[log_ybar]
	
	local percentiles  p5 p25 p50 p75 p95
	local j = 1
	foreach x of local percentiles   {
		estimates restore fprob
		margins, dydx(log_ybar) at( (`x') log_ybar) post nose  
		local hat_n_Hybar_glm_`j' = _b[log_ybar]
		
		estimates restore fprob
		margins, eydx(log_ybar) at( (`x') log_ybar) post nose  
		local hat_e_Hybar_glm_`j' = _b[log_ybar]
	local `j++'
	}
	
	**** improved standard model for semi-elasticities

	gen ln_y = log(y)
	gen log_ybar_z = log(ybar/z)

	*** ISM with elas
	reg d.ln_y d.c.log_ybar d.c.log_ybar#(c.l.log_ybar_z c.l.log_gini) d.c.log_gini d.c.log_gini#(c.l.log_ybar_z c.l.log_gini),  r
	estimates store ism_e
	gen e_Hy_ols =  _b[d1.log_ybar] + ///
		_b[cD.log_ybar#cL.log_ybar_z]  * c.l.log_ybar_z + ///
		_b[cD.log_ybar#cL.log_gini] * c.l.log_gini
		
	sum e_Hy_ols 

	margins, dydx(cD.log_ybar) post nose
	local hat_e_Hybar_ols = _b[cD.log_ybar]
	
	local percentiles  p5 p25 p50 p75 p95
	local j = 1
	foreach x of local percentiles   {
		estimates restore ism_e
		margins, dydx(cD.log_ybar) at( (`x') cL.log_ybar_z) post nose
		local hat_e_Hybar_ols_`j' = _b[cD.log_ybar]
	local `j++'
	}


	*** ISM with semi-elas
	reg d.y d.c.log_ybar d.c.log_ybar#(c.l.log_ybar_z c.l.log_gini) d.c.log_gini d.c.log_gini#(c.l.log_ybar_z c.l.log_gini),  r
	estimates store ism_n
	gen n_Hy_ols =  _b[d1.log_ybar] + ///
		_b[cD.log_ybar#cL.log_ybar_z]  * c.l.log_ybar_z + ///
		_b[cD.log_ybar#cL.log_gini] * c.l.log_gini
		
	sum n_Hy_ols 

	margins, dydx(cD.log_ybar)  post nose  
	local hat_n_Hybar_ols = _b[cD.log_ybar]
	
	local percentiles  p5 p25 p50 p75 p95
	local j = 1
	foreach x of local percentiles   {
		estimates restore ism_n
		margins, dydx(cD.log_ybar) at( (`x') cL.log_ybar_z) post nose
		local hat_n_Hybar_ols_`j' = _b[cD.log_ybar]
	local `j++'
	}

	* the truth
	mean e_Hybar*  n_Hybar*
	
	* save
	post buffer (_b[e_Hybar]) (_b[n_Hybar]) (_b[e_Hybar_1]) (_b[n_Hybar_1]) ///
		(_b[e_Hybar_2]) (_b[n_Hybar_2]) (_b[e_Hybar_3]) (_b[n_Hybar_3]) ///
		(_b[e_Hybar_4]) (_b[n_Hybar_4]) (_b[e_Hybar_5]) (_b[n_Hybar_5]) ///
		(`hat_e_Hybar_glm') (`hat_n_Hybar_glm') (`hat_e_Hybar_glm_1') (`hat_n_Hybar_glm_1') ///
		(`hat_e_Hybar_glm_2') (`hat_n_Hybar_glm_2') (`hat_e_Hybar_glm_3') (`hat_n_Hybar_glm_3') ///
		(`hat_e_Hybar_glm_4') (`hat_n_Hybar_glm_4') (`hat_e_Hybar_glm_5') (`hat_n_Hybar_glm_5') ///
		(`hat_e_Hybar_ols') (`hat_n_Hybar_ols') (`hat_e_Hybar_ols_1') (`hat_n_Hybar_ols_1') ///
		(`hat_e_Hybar_ols_2') (`hat_n_Hybar_ols_2') (`hat_e_Hybar_ols_3') (`hat_n_Hybar_ols_3') ///
		(`hat_e_Hybar_ols_4') (`hat_n_Hybar_ols_4') (`hat_e_Hybar_ols_5') (`hat_n_Hybar_ols_5') 

	}
	
}

postclose buffer


use ./data/mcs, clear


summarize hat_n_Hy* n_Hy*

summarize hat_e_Hy* e_Hy*


d hat_e_Hybar_glm*, varlist
local l_over "`r(varlist)'"
d e_Hybar*, varlist
local l_true "`r(varlist)'"
di "`l_true'"
d hat_e_Hybar_ols*, varlist
local l_ols "`r(varlist)'"

mat results = J(6,7,.)
mat li results


local r = 1
foreach i of local l_over {
	dis "`i'"
	*dis "`r'"
	loca c_truth:  word `r' of `l_true'
	dis "`c_truth'"
	loca c_ols:  word `r' of `l_ols'
	dis "`c_ols'"
	
	mean `c_truth' 
	mat results[`r',1] = _b[`c_truth']

	***glm
	gen bias_yhat_`r' = `i'  - `c_truth'
	gen mse_yhat_`r' = (`i'  - `c_truth')^2
	
	mean `i' `c_truth' *_yhat_*
	drop bias_yhat_`r' mse_yhat_`r'

	mat results[`r',2] = _b[`i'] 
	mat results[`r',3] = abs(_b[bias_yhat_`r']/_b[`c_truth'])
	mat results[`r',4] = sqrt(_b[mse_yhat_`r'])
	
	***ols
	gen bias_yhat_`r' = `c_ols'  - `c_truth'
	gen mse_yhat_`r' = (`c_ols'  - `c_truth')^2
	
	mean `c_ols' `c_truth' *_yhat_*
	drop bias_yhat_`r' mse_yhat_`r'

	mat results[`r',5] = _b[`c_ols'] 
	mat results[`r',6] = abs(_b[bias_yhat_`r']/_b[`c_truth'])
	mat results[`r',7] = sqrt(_b[mse_yhat_`r'])
	
	local `r++'
}


mat li results

frmttable  using ./tables/Table_C_2.tex, store(tab1) s(results) ///
	ctitles("", " Actual ",  " GLM ", "MRE", "RMSE", "OLS", "MRE", "RMSE" ) ///
	var sf(f) sd(4)  rtitle("Mean" \ "P(5)" \ "P(25)"  \ "P(50)"  \ "P(75)"  \ "P(95)") replace tex fragment


d hat_n_Hybar_glm*, varlist
local l_over "`r(varlist)'"
d n_Hybar*, varlist
local l_true "`r(varlist)'"
di "`l_true'"
d hat_n_Hybar_ols*, varlist
local l_ols "`r(varlist)'"

mat results = J(6,7,.)
mat li results

local r = 1
foreach i of local l_over {
	dis "`i'"
	*dis "`r'"
	loca c_truth:  word `r' of `l_true'
	dis "`c_truth'"
	loca c_ols:  word `r' of `l_ols'
	dis "`c_ols'"
	
	mean `c_truth' 
	mat results[`r',1] = _b[`c_truth']

	***glm
	gen bias_yhat_`r' = `i'  - `c_truth'
	gen mse_yhat_`r' = (`i'  - `c_truth')^2
	
	mean `i' `c_truth' *_yhat_*
	drop bias_yhat_`r' mse_yhat_`r'

	mat results[`r',2] = _b[`i'] 
	mat results[`r',3] = abs(_b[bias_yhat_`r']/_b[`c_truth'])
	mat results[`r',4] = sqrt(_b[mse_yhat_`r'])
	
	***ols
	gen bias_yhat_`r' = `c_ols'  - `c_truth'
	gen mse_yhat_`r' = (`c_ols'  - `c_truth')^2
	
	mean `c_ols' `c_truth' *_yhat_*
	drop bias_yhat_`r' mse_yhat_`r'

	mat results[`r',5] = _b[`c_ols'] 
	mat results[`r',6] = abs(_b[bias_yhat_`r']/_b[`c_truth'])
	mat results[`r',7] = sqrt(_b[mse_yhat_`r'])
	
	local `r++'
}


mat li results

frmttable  using ./tables/Table_C_2.tex, append(tab1) s(results) ///
	ctitles("", " Actual ",  " GLM ", "MRE", "RMSE", "OLS", "MRE", "RMSE" ) ///
	var sf(f) sd(4)  rtitle("Mean" \ "P(5)" \ "P(25)"  \ "P(50)"  \ "P(75)"  \ "P(95)") replace tex fragment

***********************************
*% EOF
