************** Parms **************
clear *
set more off
global path ~/replication_eer

************* Prelims *************

set seed 20202 // seed
local R = 1000 // replications
local N = 100
local t = 10
local T = 10000 // number of bernoulli trials

************ Table C-3 ************

* log normal
do ./mc_distributions/simulate_ln_H_differentquantiles.do `R' `N' `t' `T' 

* weibull
do ./mc_distributions/simulate_weibull_H_differentquantiles.do `R' `N' `t' `T' 

* fisk
do ./mc_distributions/simulate_fisk_H_differentquantiles.do `R' `N' `t' `T' 

* dagum
do ./mc_distributions/simulate_dagum_H_differentquantiles.do `R' `N' `t' `T' 

* singh-maddala
do ./mc_distributions/simulate_sm_H_differentquantiles.do `R' `N' `t' `T' 

*** accumulate matrix 

use ./data/ln_differentquantiles, clear

sum avg_mse
di sqrt(r(mean))
sum

mat results = J(6,5,.)
mat li results

local l_over mean p5 p25 p50 p75 p95
local r = 1
foreach i of local l_over {
	dis "`i'"
	dis "`r'"

	gen bias_yhat_`i' = yhat_`i'  - y_`i'
	gen mse_yhat_`i' = (yhat_`i'  - y_`i')^2
	sum yhat_`i', meanonly
*	gen sd_yhat_`i' = (yhat_`i' - `r(mean)')^2
	
	mean *_`i'

	mat results[`r',1] = _b[y_`i']
	mat results[`r',2] = _b[yhat_`i']
	mat results[`r',3] = _b[bias_yhat_`i']
	mat results[`r',4] = abs(_b[bias_yhat_`i']/_b[y_`i'])
	mat results[`r',5] = sqrt(_b[mse_yhat_`i'])
	local `r++'
}

mat li results

frmttable  using ./tables/Table_C_3.tex,  store(tab1) s(results) ctitles("", " Actual ",  " Estimate ", "Error", "MRE", "Root-MSE" ) ///
	var sf(f) sd(4)  rtitle("Mean of $ H_{it} $" \ "\dots $ P_5 $" \ "\dots $ P_{25} $ "  \ "\dots $ P_{50} $"  \ "\dots $ P_{75} $"  \ "\dots $ P_{95} $") replace tex fragment

use ./data/weibull_differentquantiles, clear

sum avg_mse
di sqrt(r(mean))
sum


mat results = J(6,5,.)
mat li results

local l_over mean p5 p25 p50 p75 p95
local r = 1
foreach i of local l_over {
	dis "`i'"
	dis "`r'"

	gen bias_yhat_`i' = yhat_`i'  - y_`i'
	gen mse_yhat_`i' = (yhat_`i'  - y_`i')^2
	sum yhat_`i', meanonly
*	gen sd_yhat_`i' = (yhat_`i' - `r(mean)')^2
	
	mean *_`i'

	mat results[`r',1] = _b[y_`i']
	mat results[`r',2] = _b[yhat_`i']
	mat results[`r',3] = _b[bias_yhat_`i']
	mat results[`r',4] = abs(_b[bias_yhat_`i']/_b[y_`i'])
	mat results[`r',5] = sqrt(_b[mse_yhat_`i'])
	local `r++'
}

mat li results

frmttable  using ./tables/Table_C_3.tex,  append(tab1) s(results) ctitles("", " Actual ",  " Estimate ", "Error", "MRE", "Root-MSE" ) ///
	var sf(f) sd(4)  rtitle("Mean of $ H_{it} $" \ "\dots $ P_5 $" \ "\dots $ P_{25} $ "  \ "\dots $ P_{50} $"  \ "\dots $ P_{75} $"  \ "\dots $ P_{95} $") replace tex fragment

use ./data/fisk_differentquantiles, clear

sum avg_mse
di sqrt(r(mean))
sum


mat results = J(6,5,.)
mat li results

local l_over mean p5 p25 p50 p75 p95
local r = 1
foreach i of local l_over {
	dis "`i'"
	dis "`r'"

	gen bias_yhat_`i' = yhat_`i'  - y_`i'
	gen mse_yhat_`i' = (yhat_`i'  - y_`i')^2
	sum yhat_`i', meanonly
*	gen sd_yhat_`i' = (yhat_`i' - `r(mean)')^2
	
	mean *_`i'

	mat results[`r',1] = _b[y_`i']
	mat results[`r',2] = _b[yhat_`i']
	mat results[`r',3] = _b[bias_yhat_`i']
	mat results[`r',4] = abs(_b[bias_yhat_`i']/_b[y_`i'])
	mat results[`r',5] = sqrt(_b[mse_yhat_`i'])
	local `r++'
}

mat li results

frmttable  using ./tables/Table_C_3.tex, append(tab1) s(results) ctitles("", " Actual ",  " Estimate ", "Error", "MRE", "Root-MSE" ) ///
	var sf(f) sd(4)  rtitle("Mean of $ H_{it} $" \ "\dots $ P_5 $" \ "\dots $ P_{25} $ "  \ "\dots $ P_{50} $"  \ "\dots $ P_{75} $"  \ "\dots $ P_{95} $") replace tex fragment


use ./data/dagum_differentquantiles, clear

sum avg_mse
di sqrt(r(mean))
sum


mat results = J(6,5,.)
mat li results

local l_over mean p5 p25 p50 p75 p95
local r = 1
foreach i of local l_over {
	dis "`i'"
	dis "`r'"

	gen bias_yhat_`i' = yhat_`i'  - y_`i'
	gen mse_yhat_`i' = (yhat_`i'  - y_`i')^2
	sum yhat_`i', meanonly
*	gen sd_yhat_`i' = (yhat_`i' - `r(mean)')^2
	
	mean *_`i'

	mat results[`r',1] = _b[y_`i']
	mat results[`r',2] = _b[yhat_`i']
	mat results[`r',3] = _b[bias_yhat_`i']
	mat results[`r',4] = abs(_b[bias_yhat_`i']/_b[y_`i'])
	mat results[`r',5] = sqrt(_b[mse_yhat_`i'])
	local `r++'
}

mat li results
frmttable  using ./tables/Table_C_3.tex,  append(tab1) s(results) ctitles("", " Actual ",  " Estimate ", "Error", "MRE", "Root-MSE" ) ///
	var sf(f) sd(4)  rtitle("Mean of $ H_{it} $" \ "\dots $ P_5 $" \ "\dots $ P_{25} $ "  \ "\dots $ P_{50} $"  \ "\dots $ P_{75} $"  \ "\dots $ P_{95} $") replace tex fragment



use ./data/sm_differentquantiles, clear

sum avg_mse
di sqrt(r(mean))
sum

mat results = J(6,5,.)
mat li results

local l_over mean p5 p25 p50 p75 p95
local r = 1
foreach i of local l_over {
	dis "`i'"
	dis "`r'"

	gen bias_yhat_`i' = yhat_`i'  - y_`i'
	gen mse_yhat_`i' = (yhat_`i'  - y_`i')^2
	sum yhat_`i', meanonly
*	gen sd_yhat_`i' = (yhat_`i' - `r(mean)')^2
	
	mean *_`i'

	mat results[`r',1] = _b[y_`i']
	mat results[`r',2] = _b[yhat_`i']
	mat results[`r',3] = _b[bias_yhat_`i']
	mat results[`r',4] = abs(_b[bias_yhat_`i']/_b[y_`i'])
	mat results[`r',5] = sqrt(_b[mse_yhat_`i'])
	local `r++'
}

mat li results

frmttable  using ./tables/Table_C_3.tex,  append(tab1) s(results) ctitles("", " Actual ",  " Estimate ", "Error", "MRE", "Root-MSE" ) ///
	var sf(f) sd(4)  rtitle("Mean of $ H_{it} $" \ "\dots $ P_5 $" \ "\dots $ P_{25} $ "  \ "\dots $ P_{50} $"  \ "\dots $ P_{75} $"  \ "\dots $ P_{95} $") replace tex fragment

***********************************
*% EOF
