###################################################
### Creates all figures from poverty accounting ###
###################################################

rm(list=ls())

setwd("~/replication_eer")

require("readstata13")
require("ggplot2")
require("scales")
require("reshape2")
require("gridExtra")
require("strucchange")
require("tikzDevice")
source("./includes/multiplot.R")

cbPalette <- c("#56B4E9", "#000000", "#CC79A7", "#009E73", "#E69F00", "#0072B2")


ppanel <- read.dta13("./data/forRwithPCE.dta")

############### Figure 1 ############### 

plot1 <-  ggplot(ppanel, aes(x=log(mean), y=qnorm(h_200d))) +
        facet_wrap( ~ regWB, ncol = 3) +
        geom_point(size=2, shape=16, color=cbPalette[2]) +
        geom_smooth(method="lm", color="black", se = FALSE) +
        theme_bw(base_size = 14) +
        xlab("Log mean income ($\\ln \\bar{y}_{it}$)") + ylab("Inverse normal headcount ($\\Phi^{-1}(H_{it})$)")

tikz(file = "./figures/Figure_1.tex", width = 12, height = 8,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
plot1
dev.off()
path <- getwd()
setwd("./figures/")
tools::texi2dvi("Figure_1.tex", pdf=T)
system(paste(getOption("pdfviewer"),"Figure_1.pdf"))
setwd(path)

########################################

############## Figure A-2 ############## 

plot1 <-  ggplot(ppanel, aes(x=log(gini), y=qnorm(h_200d))) +
        facet_wrap( ~ regWB, ncol = 3) +
        geom_point(size=2, shape=16, color=cbPalette[2]) +
        geom_smooth(method="lm", color="black", se = FALSE) +
        theme_bw(base_size = 14) +
        xlab("Log Gini ($\\ln G_{it}$)") + ylab("Inverse normal headcount ($\\Phi^{-1}(H_{it})$)")

tikz(file = "./figures/Figure_A_2.tex", width = 12, height = 8,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
plot1
dev.off()
path <- getwd()
setwd("./figures/")
tools::texi2dvi("Figure_A_2.tex", pdf=T)
system(paste(getOption("pdfviewer"),"Figure_A_2.pdf"))
setwd(path)

########################################

############## Figure A-3 ############## 

plot1 <-  ggplot(ppanel, aes(x=ryear, y=h_200d)) +
        facet_wrap( ~ regWB, ncol = 3) +
        geom_point(size=2, shape=16, color=cbPalette[2]) +
        geom_smooth(method="lm", color="black", se = FALSE) +
        theme_bw(base_size = 14) +
        xlab("Year") + ylab("Poverty headcount $(H_{it})$")

tikz(file = "./figures/Figure_A_3.tex", width = 12, height = 8,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
plot1
dev.off()
path <- getwd()
setwd("./figures/")
tools::texi2dvi("Figure_A_3.tex", pdf=T)
system(paste(getOption("pdfviewer"),"Figure_A_3.pdf"))
setwd(path)

########################################

############### Figure 2 ############### 

## upper panel

df <- read.dta13("./data/novarpredict_eG_ybar.dta")
df2 <- read.dta13("./data/novarpredict_eY_ybar.dta")
names(df2) <- names(df)  <-  2^seq(-2,3,.2)

long.data <- melt(df)
long.data <- cbind(long.data, melt(df2, value.name="eHy")[,2])
long.data$Gini <- rep(seq(0.25,0.95,0.1),26)
names(long.data) <- c("PLtoY", "eHG", "eHy", "Gini")
long.data$ginifac <- as.factor(long.data$Gini)
long.data$PLtoY <-  rep(2^seq(-2,3,.2), each=8)

p1 <- qplot(data=long.data,x=PLtoY,y=eHy,group=ginifac,  size= I(1.2),
            geom = "line", linetype=ginifac, 
            ylab="$\\hat{\\varepsilon}^{H \\bar{y}}$", 
            xlab="$\\bar{y}_t/z$") + theme_bw(base_size = 14) +   
        theme(legend.position="none") +
        scale_x_continuous(trans = 'log2',
                           breaks = trans_breaks('log2', function(x) 2^x),
                           labels = trans_format('log2', math_format(2^.x)))

p2 <- qplot(data=long.data,x=PLtoY,y=eHG,group=ginifac, size= I(1.2),
            geom = "line", linetype=ginifac, 
            ylab="$\\hat{\\varepsilon}^{HG}$", 
            xlab="$\\bar{y}_t/z$") + theme_bw(base_size = 14) +  
        labs(colour="$G_t$", linetype="$G_t$") +         theme(legend.justification=c(0,0.95), legend.position=c(0.01,.97))  +
        scale_x_continuous(trans = 'log2',
                           breaks = trans_breaks('log2', function(x) 2^x),
                           labels = trans_format('log2', math_format(2^.x)))

tikz(file = "./figures/Figure_2_a.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
multiplot(p1,p2, layout=matrix(c(1,2), nrow=1, byrow=TRUE))
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2dvi("Figure_2_a.tex",pdf=T)
# View it:
system(paste(getOption("pdfviewer"),"Figure_2_a.pdf"))

setwd(path)

## lower panel

df <- read.dta13("./data/novarpredict_dG_ybar.dta")
df2 <- read.dta13("./data/novarpredict_dY_ybar.dta")
names(df2) <- names(df)  <-  2^seq(-2,3,.2)

long.data <- melt(df)
long.data <- cbind(long.data, melt(df2, value.name="eHy")[,2])
long.data$Gini <- rep(seq(0.25,0.95,0.1),26)
names(long.data) <- c("PLtoY", "dHG", "dHy", "Gini")
long.data$ginifac <- as.factor(long.data$Gini)
long.data$PLtoY <-  rep(2^seq(-2,3,.2), each=8)

p3 <- qplot(data=long.data,x=PLtoY,y=dHy,group=ginifac,  size= I(1.2),
            geom = "line", linetype=ginifac, 
            ylab="$\\hat{\\eta}^{H \\bar{y}}$", 
            xlab="$\\bar{y}_t/z$") + theme_bw(base_size = 14) +   
        theme(legend.position="none") +
        scale_x_continuous(trans = 'log2',
                           breaks = trans_breaks('log2', function(x) 2^x),
                           labels = trans_format('log2', math_format(2^.x)))

p4 <- qplot(data=long.data,x=PLtoY,y=dHG,group=ginifac, size= I(1.2),
            geom = "line", linetype=ginifac, 
            ylab="$\\hat{\\eta}^{HG}$", 
            xlab="$\\bar{y}_t/z$") + theme_bw(base_size = 14) +  
        labs(colour="$G_t$", linetype="$G_t$") +         theme(legend.justification=c(0,0.95), legend.position=c(0.01,.97))  +
        scale_x_continuous(trans = 'log2',
                           breaks = trans_breaks('log2', function(x) 2^x),
                           labels = trans_format('log2', math_format(2^.x)))

tikz(file = "./figures/Figure_2_b.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
multiplot(p3,p4, layout=matrix(c(1,2), nrow=1, byrow=TRUE))
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2dvi("Figure_2_b.tex",pdf=T)
# View it:
system(paste(getOption("pdfviewer"),"Figure_2_b.pdf"))

setwd(path)

########################################

############### Figure 3 ############### 

early <- read.dta13("./data/results_2d_early.dta")
late <- read.dta13("./data/results_2d_late.dta")

p1 <- ggplot(early, aes(y=Y, x=D)) +
        geom_point(size=2, shape=16, color=cbPalette[2]) + 
        geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
        geom_hline(yintercept=0, linetype = 2) +   geom_vline(xintercept=0,  linetype = 2) + 
        ylab("Growth Component ($Y$)") +   xlab("Distribution Component ($D$)") 

p3 <- ggplot(early, aes(y=delta, x=Y)) +
        geom_point(size=2, shape=16, color=cbPalette[2]) + 
        geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
        geom_hline(yintercept=0, linetype = 2) +   geom_vline(xintercept=0,  linetype = 2) + 
        ylab("Annualized Change in Headcount Ratio") +   xlab("Growth Component ($Y$)") 

p2 <- ggplot(late, aes(y=Y, x=D)) +
        geom_point(size=2, shape=16, color=cbPalette[2]) + 
        geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
        geom_hline(yintercept=0, linetype = 2) +   geom_vline(xintercept=0,  linetype = 2) + 
        ylab("Growth Component ($Y$)") +   xlab("Distribution Component ($D$)")  

p4 <- ggplot(late, aes(y=delta, x=Y)) +
        geom_point(size=2, shape=16, color=cbPalette[2]) + 
        geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
        geom_hline(yintercept=0, linetype = 2) +   geom_vline(xintercept=0,  linetype = 2) + 
        ylab("Annualized Change in Headcount Ratio") +   xlab("Growth Component ($Y$)") 

tikz(file = "./figures/Figure_3_a.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
multiplot(p1,p2, layout=matrix(c(1,2), nrow=1, byrow=TRUE))
dev.off()

tikz(file = "./figures/Figure_3_b.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
multiplot(p3,p4, layout=matrix(c(1,2), nrow=1, byrow=TRUE))
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2pdf("./Figure_3_a.tex")
# View it:
system(paste(getOption("pdfviewer"),"Figure_3_a.pdf"))

# Compile the tex file
tools::texi2pdf("./Figure_3_b.tex")
# View it:
system(paste(getOption("pdfviewer"),"Figure_3_b.pdf"))

setwd(path)

########################################


############### Figure 4 ############### 

onedolla <- read.dta13("./data/forRgraph_125d.dta")
onedolla <- onedolla[is.na(onedolla$yhat_halfout),]

p1 <- ggplot(onedolla, aes(year)) + 
        geom_line(aes(y = Total), color="black") +  geom_point(aes(y = Total)) +
        geom_line(aes(y = ylin), color="black",  linetype = 2) + 
        geom_line(aes(y = yhat_1_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_1_2), color = "gray") +
        geom_line(aes(y = yhat_1_3), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_2_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_2_2), color = "black") +
        geom_line(aes(y = yhat_2_3), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_3_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_3_2), color = "gray") +
        geom_line(aes(y = yhat_3_3), color = "gray",  linetype = 3) +  
        geom_vline(xintercept=2010,  linetype = 3) + theme_bw(base_size = 14) +
        annotate("text", y=40, x=2000, label= "Observed Data") +
        annotate("text", y=35, x=1990, label= "Linear Trend") +
        annotate("text", y=22.5, x=2020, label= "Projections") +
        ylab("Headcount ratio at \\$1.25 a day (in \\%)") + xlab("") #+ coord_fixed(ratio=0.75)

twodolla <- read.dta13("./data/forRgraph_200d.dta")
twodolla <- twodolla[is.na(twodolla$yhat_halfout),]

p2 <- ggplot(twodolla, aes(year)) + 
        geom_line(aes(y = Total), color="black") +  geom_point(aes(y = Total)) +
        geom_line(aes(y = ylin), color="black",  linetype = 2) + 
        geom_line(aes(y = yhat_1_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_1_2), color = "gray") +
        geom_line(aes(y = yhat_1_3), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_2_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_2_2), color = "black") +
        geom_line(aes(y = yhat_2_3), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_3_1), color = "gray",  linetype = 3) +
        geom_line(aes(y = yhat_3_2), color = "gray") +
        geom_line(aes(y = yhat_3_3), color = "gray",  linetype = 3) +  
        geom_vline(xintercept=2010,  linetype = 3) + theme_bw(base_size = 14) +
        annotate("text", y=65, x=2000, label= "Observed Data") +
        annotate("text", y=55, x=1990, label= "Linear Trend") +
        annotate("text", y=40, x=2020, label= "Projections") +
        ylab("Headcount ratio at \\$2.00 a day (in \\%)") + xlab("") # + coord_fixed(ratio=0.75)


tikz(file = "./figures/Figure_4.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
multiplot(p1,p2, layout=matrix(c(1,2), nrow=1, byrow=TRUE))
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2dvi("Figure_4.tex", pdf=T)
# View it:
system(paste(getOption("pdfviewer"),"Figure_4.pdf"))
setwd(path)

########################################

ppanel <- read.dta13("./data/partials.dta")
str(ppanel)

############## Figure B-1 ############## 

# first stage
plot1 <- ggplot(ppanel, aes(y=y_tilde, x=x_tilde)) +
  geom_point(size=2, shape=16, color=cbPalette[2]) + 
  geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
  ylab("Partial Log Mean Income ($\\widetilde{\\ln \\bar{y}_{it}}$)") + 
  xlab("Partial Log Per Capita Consumption ($\\widetilde{\\ln PCE^P_{it}}$)") 

tikz(file = "./figures/Figure_B_1.tex", width = 8, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
plot1
dev.off()
path <- getwd()
setwd("./figures/")
tools::texi2dvi("Figure_B_1.tex", pdf=T)
system(paste(getOption("pdfviewer"),"Figure_B_1.pdf"))
setwd(path)

########################################

df <- read.dta13("./data/4Rgraphs_ybar.dta")
dfa <-  df[c("ccode","ryear","yhat","h_200d")]
dfm <- melt(dfa, id.vars=c("ccode","ryear"))
dfa <-  df[c("ccode","ryear","mean","gini")]
dfm <- merge(dfm, dfa, by = c("ccode","ryear"))

############## Figure B-2 ############## 

plot1 <- ggplot(dfm, aes(x=mean, y=value, color=variable, shape=variable)) +   theme_bw(base_size = 14) +
        xlab("Mean income ($\\bar{y}_{it}$)") + ylab("Poverty Headcount ($H_{it}$)") + geom_point(size=2) +
        scale_color_manual(values=cbPalette[c(2,2)],labels=c("E[H$|$X]", "Actual")) +
        scale_shape_manual(values=c(21,16), labels=c("E[H$|$X]", "Actual")) + 
        scale_fill_manual(values=cbPalette[c(2,2)]) + theme(legend.position=0)
plot2 <- ggplot(dfm, aes(x=gini, y=value, color=variable, shape=variable)) +   theme_bw(base_size = 14) +
        xlab("Gini ($G_{it}$)") + ylab("Poverty Headcount ($H_{it}$)") + geom_point(size=2) +
        scale_color_manual(values=cbPalette[c(2,2)],labels=c("E[H$|$X]", "Actual")) +
        scale_shape_manual(values=c(21,16), labels=c("E[H$|$X]", "Actual")) +
        guides(colour = guide_legend(title=NULL), shape = guide_legend(title=NULL)) +
        theme(legend.justification=c(.745,.735), legend.position=c(.955,.969)) 

tikz(file = "./figures/Figure_B_2.tex", width = 12, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
grid.arrange(plot1, plot2, nrow=1, ncol=2)
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2dvi("Figure_B_2.tex", pdf=T)
# View it:
system(paste(getOption("pdfviewer"),"Figure_B_2.pdf"))
setwd(path)

########################################

############## Figure A-1 ############## 

plot1 <- ggplot(df, aes(y=d_gini, x=d_mean)) +
            geom_point(size=2, shape=16, color=cbPalette[2]) + 
            geom_smooth(method="lm", color="black", se = FALSE) +  theme_bw(base_size = 14) +
            xlab("Annualized Change in Log Mean Income ($\\Delta \\ln \\bar{y}_{it}$)") + 
            ylab("Annualized Change in Log Gini ($\\Delta \\ln G_{it}$)") 

tikz(file = "./figures/Figure_A_1.tex", width = 8, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
plot1
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2dvi("Figure_A_1.tex", pdf=T)
# View it:
system(paste(getOption("pdfviewer"),"Figure_A_1.pdf"))

setwd(path)
########################################

############## Figure A-4 ############## 

df.dec <- read.dta13("./data/growthdecadesR.dta")
df.dec <- subset(df.dec, df.dec$regioncode=="SSF")

ts.ssa <- subset(df.dec$wtmeanreg, df.dec$regioncode=="SSF")
ts.ssa <- ts(ts.ssa, start =1985, end=2010, freq = 1)
ts.ssa

fs.ssa <- Fstats(ts.ssa ~ 1, from = .08)
plot(fs.ssa, alpha=0.05) 
sctest(fs.ssa,  from = .08)
breakpoints(fs.ssa, breaks=5)

plot(ts.ssa) 
lines(breakpoints(fs.ssa)) 

p1 <- ggplot(df.dec, aes(ryear)) +  geom_line(aes(y = wtmeanreg), color="black") +   
        geom_line(aes(y = wtmean), color="black",  linetype = 2) +
        geom_vline(xintercept=2000,  linetype = 3) + theme_bw(base_size = 14) +
        ylab("Consumption growth rates (10-yr. SMA)") + xlab("") +
        annotate("text", y=.0385, x=1992, label= "Developing world w/o Sub-Saharan Africa") +
        annotate("text", y=0.01, x=2006, label= "Sub-Saharan Africa") 

tikz(file = "./figures/Figure_A_4.tex", width = 8, height = 6,
     bg="transparent", fg="black", pointsize = 12, standAlone = TRUE)
p1
dev.off()

path <- getwd()
setwd("./figures/")

# Compile the tex file
tools::texi2pdf("./Figure_A_4.tex")
# View it:
system(paste(getOption("pdfviewer"),"Figure_A_4.pdf"))
setwd(path)

########################################
