* modified for our panel data purposes from
* Schonlau, Matthias. "Boosted regression (boosting): An intoductory tutorial and a Stata plugin." The Stata Journal (2005). 5, Number 3, pp.330-354.

cap program drop xtcross
program define xtcross, rclass
version 11.0

syntax anything [iweight/] [if/] [in], [k(numlist min=1 max=1)] [EWeight(varname)] [eif(string)] [ein(string)] [stub(string)] [loud] * 

* Initalize temporary variables.

        tempname u e A results group tempgroup yhat iid_count groupfreq
        marksample touse
	
        
* Options and syntax checks.

        if "`k'" == "" {
                local k = 5
                }
        if "`k'" == "1" {
                di in red "Number of folds must be greater than 1"
                exit 198
                }
        if `k' > _N {
                di in red "Number of folds cannot exceed number of observations"
                exit 198
                }
        if `k' > 300 {
                di in red "Number of folds cannot exceed 300"
                exit 198
                }
                
        if "`loud'" == "" {
                local qui = "qui"
                }
                
        if "`eweight'" != "" {
                local eweight = "[weight=`eweight']"
                }
                
        if "`weight'" != "" {
                local weight = "[weight=`exp']"
                }
                
        if "`eif'" != "" {
                local eif = "& `eif'"
                }
        
        if "`ein'" != "" {
                local ein = "in `ein'"
                }
                
        if "`stub'" == "" {
                local stub = "est"
                }
                
* Randomize dataset and initialize results matrix.


	qui xtset
	local pvar = r(panelvar) 
	local tvar = r(timevar) 
	bys `tvar' (`pvar'): gen `iid_count' = _n
	generate `u' = runiform() if `iid_count'==1

	xtile `tempgroup'=`u' if `iid_count'==1, n(`k')
	bys `tvar' (`pvar'): egen `group' = max(`tempgroup')
	
	tab  `group', matcell(`groupfreq')
	xtset

        mat `results' = J(`k',3,.)
        local rnames
                forvalues i=1/`k' {
                        local rnames "`rnames' "`stub'`i'""
                        }
        matrix rownames `results' = `rnames'
        
* Fit models and calculate errors.
        
        forvalues i=1/`k' {
	
		preserve
		qui {
			cap drop Ti
			bys ccode_cov (ryear): gen x_Ti = _N  if `group'!=`i'
			bys ccode_cov (ryear): egen Ti = max(x_Ti) 

			tab Ti if ~anymiss, gen(Ti_)

			tab stype if ~anymiss, gen(S_)

			bys ccode_cov (ryear): egen x_ln_mean_bar = mean(ln_mean) if `group'!=`i'
			bys ccode_cov (ryear): egen x_ln_gini_bar = mean(ln_gini) if `group'!=`i'
			bys ccode_cov (ryear): egen x_Sb_2 = mean(S_2) if `group'!=`i'
			bys ccode_cov (ryear): egen x_Sb_3 = mean(S_3) if `group'!=`i'
			bys ccode_cov (ryear): egen x_Sb_4 = mean(S_4) if `group'!=`i'

			bys ccode_cov (ryear): egen ln_mean_bar = max(x_ln_mean_bar) 
			bys ccode_cov (ryear): egen ln_gini_bar = max(x_ln_gini_bar) 
			bys ccode_cov (ryear): egen Sb_2 = max(x_Sb_2) 
			bys ccode_cov (ryear): egen Sb_3 = max(x_Sb_3)
			bys ccode_cov (ryear): egen Sb_4 = max(x_Sb_4) 

			forv j = 1981(1)2010 {
				gen y_`j' =  (ryear==`j') 
				bys ccode_cov (ryear): egen x_yb_`j' = mean(y_`j') if `group'!=`i'
				bys ccode_cov (ryear): egen yb_`j' = max(x_yb_`j') 
			}

			drop x_*
		}

                `qui' `anything' `weight'                                                                       if `group' != `i' & `touse'  , `options'
                local depvar = e(depvar)
                cap estimates store `stub'`i'
                        
                qui predict `yhat'                                                                                      if `group' == `i' `eif' `ein'
              	
                * Generate error term
                           
                qui gen `e' = (`yhat'-`depvar')*(`yhat'-`depvar') if `group' == `i' `eif' `ein'
                qui tabstat `e' `eweight' if `group' == `i' `eif' `ein', save
                mat `A'  = r(StatTotal)
                local mean = `A'[1,1]
                mat `results'[`i',1]  = sqrt(`mean')
				
		cap drop `e'
				
                qui gen `e' = abs(`yhat'-`depvar') if `group' == `i' `eif' `ein'
                qui tabstat `e' `eweight' if `group' == `i' `eif' `ein', save
                mat `A' = r(StatTotal)
                local mean = `A'[1,1]
                mat `results'[`i',2]  = (`mean')
                * Generate pseudo r-squared.
                qui corr `yhat' `depvar'
                mat `results'[`i',3]  = r(rho)*r(rho)
                                
                
        drop `yhat'
        cap drop `e'
	restore

	}
        
* Return results.
        
	mat `results' = `results',`groupfreq'
        mat colnames `results' = "RMSE" "MAE" "R2" "N-Train"
        matlist `results'
        return matrix `stub'   = `results'
        
end
