*** Simulating the log-normal distribution and fit of the headcount

local R = `1'
local N = `2'
local t = `3'
local T = `4' 

cap postclose buffer
postfile buffer  yhat_mean yhat_p5 yhat_p25 yhat_p50 yhat_p75 yhat_p95 ///
	y_mean y_p5 y_p25 y_p50 y_p75 y_p95 avg_mse ///
	using ./data/ln_differentquantiles, replace

forvalues i=1/`R' {

	display "i is now `i'"

	quietly {
	
	drop _all

	set obs `N' 
	gen id = _n
	expand `t'
	bys id: gen t = _n

	* set poverty line
	gen z = 60.83

	* draw means
	gen mu = 4.75 + runiform(-1.75,1.75)

	* generate sigma
	gen sigma = 0.8 + runiform(-.25,.25)

	* generate incomes
	gen ybar = exp(mu + sigma^2 / 2)

	* generate ginis --> could reverse this to sigmas
	gen gini = 2*normal(sigma/sqrt(2)) -1

	* generate headcounts
	gen  H = normal( -log(ybar/z)/sigma + 1/2 * sigma )

	* draw from binomial with pr H
	gen y =  rbinomial(`T',H)/`T'

	*convert to logs
	gen log_ybar = log(ybar)
	gen log_gini = log(gini)

	xtset id t
	bys id (t): egen log_ybar_mean =  mean(log_ybar)
	bys id (t): egen log_gini_mean =  mean(log_gini)

	**estimate
	glm y log_ybar log_gini log_ybar_mean log_gini_mean, fam(bin) link(probit)	vce(cluster id)

	predict yhat
	
	sum yhat, d
	local avg = r(mean)
	local p5 = r(p5)
	local p25 = r(p25)
	local p50 = r(p50)
	local p75 = r(p75)
	local p95 = r(p95)

	gen mse_yhat = (yhat - y)^2
	sum mse_yhat, meanonly
	
	local avg_mse = r(mean)

	
	sum y, d
	
	* save
	post buffer (`avg') (`p5') (`p25') (`p50') (`p75') (`p95') ///
		(r(mean)) (r(p5)) (r(p25))  (r(p50)) (r(p75)) (r(p95)) (`avg_mse')
	}
	
}

postclose buffer

